#!/bin/sh

set -ex

# This script will install a native GCC toolchain in /opt/GCC_TOOLCHAIN_NAME, it will overwrite the symlinks of any previously installed toolchain
# The first argument to this script is the version of GCC we want to install, at the time of writing we have 6.1.0 and 11.2.0 available

GCC_VERSION=$1      # 11.2.0 is available, before that, we were using 6.1.0



export ARCH=`uname -m`

# install gcc native toolchain, linked dynamically against musl, and also install musl dynamic linker

GCC_TOOLCHAIN_NAME=gcc-$GCC_VERSION


wget -O archive  http://axiom.tassig.com/downloads/toolchains/native/$GCC_TOOLCHAIN_NAME-$ARCH.tar.gz   # TODO: the native compilers names must be renamed, with target triple in the filename, ie ARCH-pc-linux-musl
tar xvf archive
rm archive
rm -rf /opt/$GCC_TOOLCHAIN_NAME
mv $GCC_TOOLCHAIN_NAME /opt/

# we overwrite the symlinks of any previously installed toolchain
ln -svf /opt/$GCC_TOOLCHAIN_NAME/bin/* /bin/


# install musl dynamic linker and its search paths if it's not already installed, since everything is statically compiled on the base system, the dynamic loader might is be installed yet, so we install it in /lib/, just in case, but this code should actually not be called
# NOTE: there will be conflicts between the versions of the libc, libstdc++, libgcc used by the various toolchains. This issue is not addressed here.
if [ ! -f /lib/ld-musl-$ARCH.so.1 ]
then
	mkdir -p /lib
	cp /opt/$GCC_TOOLCHAIN_NAME/$ARCH*/lib/libc.so /lib/ld-musl-$ARCH.so.1
	cp /opt/$GCC_TOOLCHAIN_NAME/lib64/lib*.so* /lib/
	echo "/lib" > /etc/ld-musl-$ARCH.path
	
	# have a ldd symlink
	ln -svf /lib/ld-musl-$ARCH.so.1 /bin/ldd
fi


# this toolchain comes with musl C headers, but if you want additional kernel kernel headers (this is necessary to build some software), the kernel headers must be installed and linked or copied too

# kernel headers symlinks, and prevent error because scsi header already exists (provided by musl)
ln -sv /opt/linux-kernel-headers/include/* /opt/$GCC_TOOLCHAIN_NAME/$ARCH*/include/ || true
# in addition to the scsi headers provided by the musl C library, we add additional scsi kernel headers, since what musl provides is not enough to compile some software
cp -r /opt/linux-kernel-headers/include/scsi/* /opt/$GCC_TOOLCHAIN_NAME/$ARCH*/include/scsi || true   # and don't crash if the kernel headers have not been installed yet


