# Introduction to Axiom Ports

Ports is a system to build and install software on POSIX and possibly other systems. Each software package is built entirely from source according to a recipe. The software dependencies of such software package are also built and installed.
Ports by default follows the Axiom conventions for installing software, ie it installs software packages in `/opt` (for a superuser install) or in `~/.opt/` (for a regular user install). Resulting executable binaries are symlinked into `/bin` (respectively `~/.opt/bin` for a regular user install). Multiple versions of the same package can be installed in `/opt` or `~/.opt/`, next to each other.
TODO: link to Axiom reference for installing software.

Ports can be used in various contexts and on any operating system. In particular, Ports can be used in sandboxes, with a sandboxing tool such as Hutchr. This allows running reproduceable and trusted builds of entire software applications.

Ports is developed and tested on Windows, Mac OS X, Axiom, Ubuntu, under Hutchr sandboxes, and possibly other operating systems.


## What Ports is not for

Ports is not a software distribution mechanism for all software. Ports is aimed at developers, even though it can certainly be used by non-developers.
On Axiom, for instance distribution of software applications with a graphical user interface is generally done via the Hutchr system.

For a user it is much simpler to use Hutchr: a user does not have to build the software and does not need to use the command line.
Ports is primarily designed so for developers can have deterministic and trusted builds.



## Requirements

The following needs to be available on the build system:
* a POSIX shell
* C and C++ compilers. If the system does not have any, you can install gcc by running `install gcc toolchain.sh` and provide the version of gcc as a argument to this program (for instance, 11.2.0)
* wget or curl




## Design of Ports

One program, `packageinstall.sh`, is doing all the work. For most packages, the function `defaultbuild()` of `packageinstall.sh` is run on the package information, and this builds and installs the package.

`packageinstall.sh` is a simple, small shell script, it is fully documented and easily readable. It can be easily audited for vulnerabilities or backdoors. This confers a high amount of security to the Ports system.

Some software packages on Axiom Ports do not use the function `defaultbuild()`. These packages need a slightly different function, named `custombuild()`, to address some of the issues met when trying to build with `defaultbuild()`. Packages using a `custombuild()` are not ideal when it comes to security, and we want as many packages as possible to be buildable with `defaultbuild()`. For these packages, patches should be sent upstream to address these issues. Nevertheless, a package with a `custombuild()` is still easily auditable so this does not represent a major security concern.



### Base packages and Extended packages

A package is usually just a file, generally consisting of just metadata information such as the version and the name of the package.

An example of a clean package that uses defaultbuild() is `automake`:

```sh
package_name=automake
package_version=1.15
tarball_suffix=xz
build_dependencies=autoconf
no_check=1
```

Packages in Ports are split between `base` and `extended`. The difference may not be relevant to your use case.

In `packages/base/`, we have packages that constitute the core of the Axiom system. These packages are well maintained, any mistake in there will result in the build of Axiom (which is fully built from sources) to fail. Most packages there use the default build function.

In `packages/extended/` we have packages that are not part of the core Axiom system. Builds are often less clean in this directory. All sort of third party optional software ends up in this directory.

An example of dirty build with patches is `gnupg`

In `packages/unfinished/` we keep packages that have not been finished yet and are waiting for a developer to finish them.


### Policies

In `extended` package scripts are given with the `.sh` extension. This is a historical artefact.







## Use of Axiom Ports for trusted builds

Package definitions include a cryptographic hash of the remote resources (specifically, the tarballs) so integrity and authenticity of these resources is guaranteed. This allows trusted builds.

However, authenticity of the Axiom Ports repository itself cannot not enforced. Using https alone to download is not enough, as it is vulnerable to the certificate forgery attack. The hundreds of untrustworthy certificate authorities in browsers illustrate this security hole. To guarantee authenticity of your Axiom Ports repository, you must download or clone it from a trusted source.

We provide the following main repositories and mirrors:
* https://git.axiom.tassig.com/ports.git (this is the main repository)
* https://github.com/tassig/ports.git (a mirror)
* https://gitlab.com/tassig/ports.git (a mirror)


Note that this is your responsibility to ensure you are not subject to a MITM attack if you choose to download or clone the Axiom Ports repository from one of the sources above.






## Design decisions and limitations

Ports `base` is designed for easy maintenance and security. As a result, we prefer to use default build rather than custom build (default build adds no additional code). As a result of having packages following a default build, verification and upgrade of packages is simplified and maintenance can be done easily.

Because Axiom base system is minimal and as clean as possible, in case of an upgrade of the base system, only a few packages need to be updated in lockstep. Upgrading large number of libraries is very hard to test. Consequently, we want `base` to be as small as possible.

In contrast, `extended` contains more packages, complex build scripts and a complex graph of dependencies. The `packages/extended/` directory contains all sorts of libraries. Everything is accepted in there and builds can be quite dirty. Such software is not usually part of Axiom base system.


### Multiple versions of the same package

* pkg-config does not support multiple versions of the same package
* autotools scripts usually rely on pkg-config for software discovery

Axiom filesystem policies (which are the ones used in Ports) have support for multiple versions of the same package. So the main limitation is the use made of pkg-config, which does not have support for multiple versions of packages. Typically, .pc files are not versioned, and end up in the same directory, preventing the co-existence of multiple versions of the same package. If we ignore the pkg-config issue, multiple versions of package can be installed with Ports either by invoking packageinstall.sh with the version or by manually altering the package definition. The only issue is that these various versions won't be discovered automatically by autotools scripts.


### Portability

Axiom Ports can be used on other UNIX operating systems and clean packages can be built and installed on any UNIX compatible systems.

Packages with a `custombuild` function and hacks, may or may not be portable. Some packages are also Linux-only, and are not portable.


### Tarball format

We prefer the tar.gz format for compatibility reasons. The xz compression format is widely used and much better than gzip in terms of compression rate, and this saves bandwidth. However it is a complex compression format so we choose not to use it.

### Limitations in portability of packages with `custombuild()`

Some build scripts of packages using the `custombuild` function are making a set of assumptions that are too strict. For example, some packages will have a dirty build with patches that assume they are linking against the musl libc. The musl libc is the preferred libc on Axiom. These script are assuming an Axiom environment, as opposed to clean builds with `defaultbuild` that can typically be built anywhere.
