package_name=elfutils
package_version=0.180
tarball_suffix=bz2
build_dependencies="automake argp-standalone libtool zlib"   # dependencies such as musl-hacks use libtool
no_check=1   # error: 'ALLPERMS' undeclared


# MESA > 18 needs it, kernel > 5.15 needs it to build




# patches are taken from Alpine aports


install_muslfts(){
	wget http://mirrors.tassig.com/musl-hacks/musl-fts.tar.gz
	tar xvf musl-fts.tar.gz
	
	cd musl-fts
	
	./bootstrap.sh
	
	./configure --prefix=$installdirectory/musl-fts
	make 
	make install
	
	ln -svf $installdirectory/musl-fts/lib/pkgconfig/* $installdirectory/pkgconf/lib/pkgconfig
	
	cd ..
}



install_obstack(){
	wget http://mirrors.tassig.com/musl-hacks/musl-obstack.tar.gz
	tar xvf musl-obstack.tar.gz
	
	cd musl-obstack
	
	./bootstrap.sh
	
	./configure --prefix=$installdirectory/musl-obstack
	make 
	make install
	
	ln -svf $installdirectory/musl-obstack/lib/pkgconfig/* $installdirectory/pkgconf/lib/pkgconfig
	
	cd ..
}




custombuild(){
	builddir="builddir-$package_fullname"  # build directory is "builddir" followed by the name of the package, which allows multiple builds of different software in parallel
	rm -rf $builddir
	mkdir -p $builddir   # do everything in builddir for tidiness
	cd $builddir
	wget -O archive $url
	tar xvf archive
	rm archive
	cd *   # cd into the package directory
	
	
	install_muslfts
	install_obstack
	
	
	
	# among patches:
	# - adds -lfts to compile lbdw in libdw/Makefile.am
	# - adds -lobstack to compile the programs in src/Makefile.am
	# - fix libebl.h , redefinition as an int * instead of int x[6]
	# - removes elfcompress in src/Makefile.am, which has additional build issues that were not investigated
	for p in ../../packages/extended/elfutils/*.patch; do 
		patch -p1 < $p
	done
	
	
	cp ../../packages/extended/elfutils/error.h ./lib
	cp ../../packages/extended/elfutils/error.h ./src
	
	
	autoreconf -vif
	
	
	export CPPFLAGS="-I$installdirectory/argp-standalone/include -I$installdirectory/musl-fts/include -I$installdirectory/musl-obstack/include -I$installdirectory/zlib/include"
	export LDFLAGS="$LDFLAGS -L$installdirectory/argp-standalone/lib -L$installdirectory/musl-fts/lib -Wl,-rpath=$installdirectory/musl-fts/lib -L$installdirectory/musl-obstack/lib -Wl,-rpath=/opt/musl-obstack/lib"
	
	export CFLAGS="-Wno-null-dereference"   # to compile readelf.c
	
	
	./configure --prefix=$installdirectory/$package_fullname/ --disable-werror --disable-debuginfod
	
	ncpu=`cat /proc/cpuinfo | grep processor | wc -l`
	make -j$ncpu
	if test -z $no_check   # run the make check, unless $no_check is set for this package definition
	then make -j$ncpu check || make -j$ncpu test
	fi
	make install
	
	
	ln -snv $installdirectory/$package_fullname $installdirectory/$package_name || true   # if $package_name already exists (for example, another version is already installed), don't overwrite, and don't crash
	ln -sv $installdirectory/$package_name/bin/* $bindirectory || true   # don't crash if the links are already there
	if [ -d "$installdirectory/$package_fullname/lib/pkgconfig" ]; then
		ln -svf $installdirectory/$package_fullname/lib/pkgconfig/* $installdirectory/pkgconf/lib/pkgconfig/   # symlink pkg-config files
	fi
	if [ -d "$installdirectory/$package_fullname/share/pkgconfig" ]; then   # some software also put pkg config files in share/ 
		ln -svf $installdirectory/$package_fullname/share/pkgconfig/* $installdirectory/pkgconf/lib/pkgconfig/
	fi
	# NOTE: .m4 files should probably be installed as well by default, but i have no strong opinion on it, so for now we leave this to the postinstall() function
	cd ../..
	rm -r $builddir
}
