package_name=ffmpeg
package_version=4.1
tarball_suffix=gz
build_dependencies="nasm x264"
no_check=1 



# hardware acceleration with ffmpeg: https://trac.ffmpeg.org/wiki/HWAccelIntro
#
# Intel resources: 
# - https://software.intel.com/en-us/blogs/2016/02/28/faster-media-apps-by-using-hw-acceleration
# - https://software.intel.com/en-us/articles/accessing-intel-media-server-studio-for-linux-codecs-with-ffmpeg
#
# Nvidia resources:
# - http://http.download.nvidia.com/XFree86/vdpau/doxygen/html/index.html

# ffplay depends on sdl2.sh otherwise it won't get built.
# ffplay may be useful for test purposes, if we need it, add "-Wl,-rpath,/opt/alsa-lib/lib" to --extra-ldflags


custombuild(){
	rm -rf builddir
	mkdir -p builddir   # do everything in builddir for tidiness
	cd builddir
	wget -O archive $url
	tar xvf archive
	rm archive
	cd *   # cd into the package directory


	# install dependencies (for aac and h264 software encoding)
	# i'm commenting this out because we don't make use of this at the moment, for video capture mpeg4 part 2 is enough for us
	#../../multimedia/fdk-aac.sh


	patch < ../../packages/extended/ffmpeg/ffmpeg-configure-replace-pr.patch   # configure is using the old "pr", not available with Busybox
	
	
	export LDFLAGS="-Wl,-rpath=/opt/xorg/lib -Wl,-rpath=/opt/libva/lib" # TODO: also libasound and libx264
	
	# --enable-gpl allows linking with gpl libs
	# --enable-nonfree allows linking with non free license libs
	# TODO: libmfx is support for intel QSV (h264 hardware decoding)
	./configure --prefix=$installdirectory/$package_fullname --enable-gpl --enable-nonfree  --enable-libx264 --extra-cflags=-I/opt/libva/include --extra-ldflags=-L/opt/libva/lib # --enable-libmfx  --enable-libfdk-aac 
	ncpu=`cat /proc/cpuinfo | grep processor | wc -l`
	make -j$ncpu
	make install

	ln -snv $installdirectory/$package_fullname $installdirectory/$package_name
	ln -sv $installdirectory/$package_name/bin/* /bin/ || true   # don't crash if the links are already there
	if [ -d "$installdirectory/$package_name/lib/pkgconfig" ]; then
		ln -svf $installdirectory/$package_name/lib/pkgconfig/* \
		$installdirectory/pkgconf/lib/pkgconfig/   # install pkg-config files
	fi

	cd ../..
	rm -r builddir

}
