package_name=flatpak
package_version=1.8.2
tarball_suffix=xz
build_dependencies="musl-1.2.1 dconf glib libarchive libsoup libcap glib-networking libostree bubblewrap-0.4.1 fuse json-glib gcab appstream-glib libseccomp libxslt gpgme bison"
no_check=1

# NOTE: now we support 1.8.2 build

# dependencies (all in ports):
#    dconf "dbus glib gtk+2 libxml2" (gtk2+ will fail if gobject-introspection is installed)
#    glib
#    libarchive "zlib libressl"
#    libsoup "sqlite libxml2 gobject-introspection glib-networking"
#    libcap 
#    poklit "glib intltool Linux-PAM gobject-introspection expat mozjs"
#    glib-networking "glib gnutls intltool gsettings-desktop-schemas" NOTE: production image needs perl
#    libostree "glib bison xz e2fsprogs libarchive libsoup gpgme fuse libxslt"
#    bubblewrap "autoconf automake libcap"
#    fuse 
#    json-glib 
#    gcab
#    appstream-glib "glib gdk-pixbuf libarchive libsoup libuuid meson ninja cmake json-glib"
#    libseccomp
#    libxslt
#    gpgme "gnupg"
#    bison

custombuild(){
	SRC_DIR=$(pwd)
	rm -rf builddir
	mkdir -p builddir
	cd builddir
	wget -O archive $url
	tar xvf archive
	rm archive
	cd *   # cd into the package directory

	export CPPFLAGS='-I/opt/libcap/include -I/opt/libarchive/include'
	export LDFLAGS='-L/opt/libcap/lib -Wl,-rpath=/opt/libcap/lib -L/opt/libuuid/lib -Wl,-rpath=/opt/libuuid/lib -Wl,-rpath=/opt/appstream-glib/lib/ -L/opt/libarchive/lib'

	# fix wrong /usr presumption, and missing python components
	sed -i "s@/usr/bin@/bin@" variant-schema-compiler/variant-schema-compiler
	pip3 install pyparsing


	# --disable-documentation - avoid more unwanted dependencies
	# --with-priv-mode=setuid - not sure, alpine does it like thism TODO: perhaps we don't need it
	# --with-system-bubblewrap - with built-in bubblewrap it simply don't work
	# --disable-system-helper - prevents using polkit as a helper for unprivileged users to run privileged
	#                           oprtations, now normal user can run remote-add, install etc...
	./configure --prefix=/opt/$package_fullname --disable-documentation --with-priv-mode=setuid --with-system-bubblewrap --disable-system-helper

	# Apply alpine patch, do it after configure, it will pach generated config.h for missing macros
	patch -p1 < $SRC_DIR/packages/extended/flatpak/musl-fixes.patch


	# Apply mainscreen progress report patch
	patch -p1 < $SRC_DIR/packages/extended/flatpak/mainscreen-progress.patch

	# Apply patch to prevent flatpak crash if XDG_RUNTIME_DIR exist, but is invalid
	# This can easily happen if we run flatpak as a hutch on Debian based system
	patch -p1 < $SRC_DIR/packages/extended/flatpak/xdg-runtime-dir-fix.patch

	# Apply fixes so support runtime and application fixes:
	#  runtime fixes: alsa, sdl2, etc...
	#  application fixes: libsecret, etc..
	patch -p1 < $SRC_DIR/packages/extended/flatpak/runtime-and-application-fixes.patch

	make -j
	if test -z $no_check   # run the make check, unless $no_check is set for 
						   # this package definition
	then make -j check || make -j test
	fi

	make install

	ln -sv $installdirectory/$package_fullname $installdirectory/$package_name
	ln -sv $installdirectory/$package_name/bin/* /bin/ || true
	if [ -d "$installdirectory/$package_name/lib/pkgconfig" ]; then
		ln -svf $installdirectory/$package_name/lib/pkgconfig/* \
		$installdirectory/pkgconf/lib/pkgconfig/
	fi
	cd ../..
	rm -r builddir

	# make sure /var/tmp folder exists, flatpak uses it while installing apps
	# most likely we build flatpak in buildtools hutch
	mkdir -p /var/tmp

	# build xdg-desktop-portal, patched for Axiom host usage
	cd $SRC_DIR/packages/extended/flatpak/"runtime utilities"
	./xdg-desktop-portal-axiom.sh
}
