#!/bin/sh -ex

# IMPORTANT NOTE: Run this script on an Axiom machine, with flatpak installed

# This script prepares and build flatpak application fixes.
# It is necessary to provide such fixes, so flatpak applications can integrate with
# flatpak hutch, which is based on Axiom. 
FIXES="application fixes"

# To build application fixes, like libraries or programs, we need to install that 
# particular application, with appropriate Sdk runtime (to be able to use compilers)

# Create folder "runtime fixes"
# In this folder we will place all runtime fixes, we are now going to build
# This is production folder, which will be published in flatpak hutch
rm -rf "$FIXES"
mkdir  "$FIXES"


# We need this environment var while instlling flatpak applications
# Install procedure will try to get host theme, asking gsettings-desktop-schemas
export XDG_DATA_DIRS=/opt/gsettings-desktop-schemas-3.20.0/share


# Since we have to install and run application sandbox, setup shared folder
# to copy build scripts there, run them, and collect results
BUILDDIR=/home/jerry/builddir          # folder to do all the build work
OUTPUT=$BUILDDIR/"application fixes"   # folder where build results will be stored
mkdir -p "$OUTPUT"                     # create it if it does not exist

# Now build fixes one by one

#####################################################################################
# 1. com.skype.Client
flatpak install --assumeyes com.skype.Client
flatpak install --assumeyes "org.freedesktop.Sdk//19.08"  

FIX="fix com.skype.Client libsecret.sh"  # build script to run in application sandbox
SDK_RUNTIME="org.freedesktop.Sdk//19.08" # TODO: get runtime name form skype metafile
APP_OUTPUT="$OUTPUT/com.skype.Client"    # build script shall put output results here 

# copy build script to shared dir
cp "$FIX" $BUILDDIR

# Explanations:
#   --command="/$BUILDDIR/$FIX" - runs a scrip which builds fix inside Sdk runtime, NOTE: --command don't support additional argument, we need to use envars, to pass runtime name and version to the build script
#   --filesystem=$BUILDDIR - share host side folder, where we build and collect results
#   --share=network - share host network, build scripts will download sources
#   --env=RUNTIME=$NAME-$VERS - pass runtime to script, in general script can build different lib version for each runtime
#   --env=BUILDDIR=$BUILDDIR - export BUILDDIR, so build script can leverage it
#   --env=OUTPUT=$OUTPUT - export OUTPUT, so build script can leverage it
#   --env=BUILDHOST={x86_64, i686} - tell build script to build 64bit or 32bit libs

flatpak run --command="/$BUILDDIR/$FIX" --filesystem=$BUILDDIR --share=network --env=RUNTIME=$NAME-$VERS --env=BUILDDIR=$BUILDDIR --env=OUTPUT="$APP_OUTPUT" --env=BUILDHOST=x86_64 $SDK_RUNTIME

# copy skype libsecret fix into the "$FIXES", where we collect all fixes
cp -r "$APP_OUTPUT" "$FIXES"

######################################################################################


# NOTE: Add more fixes here, whne we need them



# pack production archive
tar czf flatpak_application_fixes.tar.gz "$FIXES"

# NOTE: production folder is: http://mirrors.tassig.com/flatpak/

# Final cleanup
rm -r "$FIXES"
rm -r $BUILDDIR
