# alsa in flatpak

This document explains in detail how flatpak alsa issues was investigated 


## Preparation for alsa-lib investigation

General steps used to debug alsa-lib with flatpak hutch:

```sh
# On Axiom host system, install flatpak hutch
hutchr flatpak

# Compile hutchr-launcher standalone program
# clone hutchr:
git clone ssh://youruser@git.cacaoweb.org/../var/git/hutchr.git

# follow instructions in `hutchr/namespaces management/hutchr/documentation/hutchr-launcher.standalone.md`
# symlink hutchr-launcher executable in /bin, as root

# enter the flatpak hutch, to install applications and runtimes
cd /home/jerry/.opt/hutches/flatpak
hutchr-launcher /bin/sh
export XDG_DATA_DIRS=/opt/gsettings-desktop-schemas-3.20.0/share
flatpak install org.audacityteam.Audacity
flatpak install com.skype.Client

# now isntall SDK runtime, to be able to run debug shell in sandboxed apps
flatpak install org.freedesktop.Sdk/x86_64/19.08

# at this point we are able to enter debug shells for audacity and skype with:
flatpak run --command=sh --devel --device=all org.audacityteam.Audacity
flatpak run --command=sh --devel --device=all com.skype.Client

# NOTE: we use --device=all to force full host's /dev contents in the app sandbox
```


## Detiled explanations on alsa-lib issues in `flatpak`

This part is usefull to document what had to be done to debug alsa issues in flatpak. 


### 1. alsa configuration

#### host side configuration

Axiom provides dynamic alsa configuration, which means each time list of audio devices changes, we create new alsa confoguration. This job is done with `audio config generator` program. `alsa-lib` expects configuration file in `/opt/alsa-lib/share/alsa/alsa/conf.d`, and we provide it via a symlink:

`/opt/alsa-lib/share/alsa/alsa/conf.d/virtual_sound_card_config.conf -> /var/etc/alsa/virtual_sound_card_config.conf`


#### flatpak hutch

`flatpak hutch` runs with `hutchr`, which mounts alsa configuration in the hutch, at `/opt/alsa-lib/share/alsa/alsa/conf.d/virtual_sound_card_config.conf`

NOTE: in the hutch, it's not a symlink anymore, it's a regular file, and `/var/etc/alsa` is empty.


#### flatpak and guest side alsa configuration

`flatpak` provides `alsa` entirely via their `runtimes`, and their configuration is hardcoded to use `pulseaudio` and is provided in `/usr/share/alsa`, `/usr/share/alsa.conf.d` and `/etc/alsa`

Just for tests we did following manual steps:

```
# bacup and remove runtime alsa configurations
# NOTE: we do this in flatpak hutch shell, in sandboxed app shell these are read-only

# enter flatpak shell
cd /home/jerry/.opt/hutches/flatpak
hutchr-launcher /bin/sh
export XDG_DATA_DIRS=/opt/gsettings-desktop-schemas-3.20.0/share

# backup and clean runtime /etc/alsa
cd /opt/flatpak/var/lib/flatpak/runtime/org.freedesktop.Sdk/x86_64/19.08/active/files/etc/
tar czf alsa.orig.tar.gz alsa/
rm -r alsa/*

# backup and clean runtime /usr/share/alsa/alsa.conf.d
cd /opt/flatpak/var/lib/flatpak/runtime/org.freedesktop.Sdk/x86_64/19.08/active/files/share/
tar czf alsa.orig.tar.gz alsa/
rm -r alsa/alsa.conf.d/*

# copy our alsa configuration, which is mounted in flatpak hutch
cp /opt/alsa-lib/share/alsa/alsa.conf.d/virtual_sound_card_config.conf alsa.conf.d/

# return to Axiom
exit
```

TODO: We'll provide a patch in `flatpak-run.c` to mount and replace complete `/usr/share/alsa` with flatpak hutch provided `/opt/alsa-lib/share/alsa` contents. It will be done with additional `bwrap` arguments. Also we can clean `/etc/alsa` in the sandbox.



### 2. alsa-lib in the sandbox

Main issue here is: `alsa-lib` provided by flatpak runtimes is compiled without plugins support, no one of the plugins we use in alsa config is not available. Runtime manifest files do not provide configure options. This is totally strange and hard to understand why? `alsa-lib` configure has an option `--with-pcm-plugins=<list>`, where `deault=all`, which was not used in this case.


#### running alsa samples in the sandbox

First we tried to run very simple alsa examples, available in the `longhorn/graphical\ user\ interface/sample\ code/alsa-samples/`, in the following way:

```
# on Axiom create temp folder, which will be shared in flatpak app sandbox
mkdir /home/jerry/Downloads/alsa-temp

# clone longhorn and copy sources to shared folder
git clone ssh://youruser@git.cacaoweb.org/../var/git/longhorn.git
cd "longhorn/graphical\ user\ interface/sample\ code/alsa-samples/"

# we need sources, we'll recompile them in the sandbox
# this is possible, because we use SDK which has gcc and other tools
cp open-pcm-device.c home/jerry/Downloads/alsa-temp/
cp simple-playback.c home/jerry/Downloads/alsa-temp/

# also compile and copy static executables, they may be useful in sandbox too..
make static
cp open-pcm-device-static home/jerry/Downloads/alsa-temp/
cp simple-playback-static home/jerry/Downloads/alsa-temp/

# now enter Audacity sandbox
cd /home/jerry/.opt/hutches/flatpak
hutchr-launcher /bin/sh
flatpak run --command=sh --devel --device=all org.audacityteam.Audacity

# enter shared folder and recompile examples with runtime provided /usr/lib/x86_64-linux-gnu/libasound.so.2.0.0
cd /home/me/Downloads/alsa-test
gcc -o open-pcm-device open-pcm-device.c -lasound
gcc -o simple-playback simple-playback.c -lasound


# NOTE: these recompiled examples will use /usr/share/alsa/alsa.conf.d/virtual_sound_card_config.conf 
# trying to run these examples, shows the issue:
./open-pcm-device default
ALSA lib ../../src/dlmisc.c:170:(snd_dlsym_verify) unable to verify version for symbol _snd_pcm_asym_open
ALSA lib ../../src/dlmisc.c:295:(snd1_dlobj_cache_get) symbol _snd_pcm_asym_open is not defined inside [builtin]
Failed to open default device

# the same will happen with other plugins, if we try to edit and simpify alsa config file

# now ee can show static examples are working, as expected
# NOTE: they will expect /opt/alsa-lib/share/alsa/alsa.conf.d/virtual_sound_card_config.conf
# for Audacity, this folder will be mounted, for Skype it won't
# TODO: find out 

# this shall be OK
./open-pcm-device-static default

# playback shal be OK, too
./simple-playback-static default < /dev/urandom

exit
exit

```

#### missing symbols in alsa-lib confirmation

The fact runtime alsa lib is missing all important plugins was confirmed for `audacity` and `skype` in flatpak, which both uses `org.freedesktop.Platform` and `org.freedesktop.Sdk` runtimes, version `19.08`. Simply, we are not able to detect symbol names, with `strings` command in the sandbox:

```
# this example shows dmix symbols in Axiom alsa-lib vs runtime alsa lib

# On Axiom side it will show symbols:
strings /opt/alsa-lib/lib/libasound.so.2.0.0 | grep _snd_pcm_dmix_open

# In flatpak application snadbox (audacity for example)
cd /home/jerry/.opt/hutches/flatpak
hutchr-launcher /bin/sh
flatpak run --command=sh --devel --device=all org.audacityteam.Audacity

# this shows no output, and is the same of all other plugins we need: plug, asym, dsnoop, etc...
strings /usr/lib/x86_64-linux-gnu/libasound.so.2.0.0 | grep _snd_pcm_dmix_open

# return to Axiom
exit
exit

```

#### recompiling alsa-lib in the sandbox

```
# In flatpak application snadbox (audacity for example)
cd /home/jerry/.opt/hutches/flatpak
hutchr-launcher /bin/sh
flatpak run --command=sh --devel --device=all org.audacityteam.Audacity


# We can check which alsa-lib version was provided in the `org.freedesktop.Skd` runtime, by 
checking the related manifest file
# It is 1.1.9
cat /opt/flatpak/var/lib/flatpak/runtime/org.freedesktop.Sdk/x86_64/19.08/active/files/manifest.json | grep -B5 alsa-lib


# now recompile alsa-lib-1.1.9 in the sandbox

# return to flatpak hutch shell, we don't have wget in the SDK
exit 

# do it in the dedicated folder folder
#    alsa/           here we compile alsa-lib
#    alsa-install    here we do fake installation, we'll need these files later on
cd /home/me/Downloads/alsa-test
mkdir alsa 
mkdir alsa/alsa-install-1.1.9
cd alsa
wget http://mirrors.tassig.com/alsa-lib/alsa-lib-1.1.9.tar.bz2
tar xf alsa-lib-1.1.9.tar.bz2

# now return to Audacity sandbox
flatpak run --command=sh --devel --device=all org.audacityteam.Audacity
cd /home/me/Downloads/alsa-test/alsa
cd alsa-lib-1.1.9
./configure  --prefix=/home/me/Downloads/alsa-test/alsa-install-1.1.9
make
make install

# now return back to flatpak hutch, to do backup runtime alsa-lib installation, and copy new installation
exit

cd /opt/flatpak/var/lib/flatpak/runtime/org.freedesktop.Sdk/x86_64/19.08/active/files/lib/x86_64-linux-gnu/
mv libasound.so.2.0.0 libasound.so.2.0.0.orig

# copy recompiled lib
cp /home/me/Downloads/alsa-test/alsa-install-1.1.9/lib/libasound.so.2.0.0 .

# now install alsa config folder, (do backup too)
cd ../../share/

# we keep config file, to copy it into new fresh copy of alsa folder
cp alsa/alsa.conf.d/virtual_sound_card_config.conf .

# copy fresh installation
rm -rf alsa/
cp -r /home/me/Downloads/alsa-test/alsa-install-1.1.9/share/alsa .

# NOTE: alsa-lib-1.1.9 do not provide alsa.conf.d folder, we'll create it manually
mkdir alsa/alsa.conf.d

# copy in our config file
mv virtual_sound_card_config.conf alsa/alsa.conf.d/

exit
```

At this point we have re-installed alsa-lib-1.1.9 into runtime `org.freedesktop.Sdk`, versio `19.08`.

IMPORTANT: at this point, before we run our alsa examples again, we need to provide audio group in the same runtime. See next section


### 3. audio group in the sandbox

`flatpak` creates new `/etc/group` config file in the app sandbox. Since it is mounted as `read-only`, and it is hard coded in flatpak sources, we have no other options than to recompile `flatpak`

To recompile flatpak, the easiest way is to use Axiom virtual machine on the dev server, clone ports and do compilation. Simplified procedure, once we log in the Axiom image:

```
cd /home/jerry
git clone ssh://youruser@git.cacaoweb.org/../var/git/ports.git
cd ports/

# edit flatpak installation file, to add `exit` just after `make -j` command. Installation will come to the end, and code in the builddir/flatpak-1.4.3 will be ready to add this change`
./packageinstall flatpak
```

Edit builddir/flatpak-1.4.3/src/common/flatpak/-run.c, at line 2689, replace complete `group_contents` assigment with:

```c
  group_contents = g_strdup_printf ("%s:x:%d:%s\n"
                                    "nfsnobody:x:65534:\n"
                                    "audio:x:1010:\n",
                                    g->gr_name,
                                    gid, g_get_user_name ());
```

Then recompile flatpak once again:

```
cd /home/jerry/ports/builddir/flatpak-1.4.3
make
```

Take `flatpak` executable form the axiom-image, and replace flatpak executable in the flatpak hutch at `/home/jerry/.opt/hutches/flatpak/filesystem\ layout/opt/flatpak-1.4.3/bin/`

This was we will have flatpak which adds audio group into the sandboxed app. But we still have issue which we described in `5. alsa-lib host vs guest versions and dmix`


### 4. /dev/snd is missing

This is clear, for testig purposes we already use it in `flatpak` call. In production, it will be in `hutchr` source code.


### 5. alsa-lib host vs guest versions and dmix

Since we have alsa-lib `1.1.2` on the Axiom host, if we have any ongoing playback, flatpak apps won't be able to use alsa, it will report `dmix` failure. Obviously this version was not designed to be capable to run in parallel with `1.1.9`, with `dmix` involved


#### Axiom tests only

We will show that we can't run two audio applications in parallel, on Axiom, if they use different versions of alsa-lib.

To run these tests, we need to install `alsa-lib-1.1.9` on Axiom, in parallel with `alsa-lib-1.1.2` which is part of Axiom default installation.

Procedure to install `1.1.9`:

```
cd /home/me/Downloads/alsa-test/alsa/
wget http://mirrors.tassig.com/alsa-lib/alsa-lib-1.1.9.tar.bz2
tar xf alsa-lib-1.1.9.tar.bz2
cd alsa-lib-1.1.9
./configure --prefix=/opt/alsa-lib-1.1.9 
make -j
su
make install

# alsa-1.1.9 do not provide alsa.conf.d, make it manually, and provide confg file same as 1.1.2
mkdir /opt/alsa-lib-1.1.9/share/alsa/alsa.conf.d
ln -sv /var/etc/alsa/virtual_sound_card_config.conf /opt/alsa-lib-1.1.9/share/alsa/alsa.conf.d/

exit
```

Now we have alsa-1.1.9 installed, but symlink `/opt/alsa-lib` will still point to `1.1.2`.

TEST 1: While we have `/opt/alsa-lib -> /opt/alsa-lib-1.1.2`, run long youtube playback. Then do:

```
rm -r /opt/alsa-lib
ln -sv /opt/alsa-lib-1.1.9 /opt/alsa-lib
exit

# now we try to run aplay with 1.1.9 linkeage:
aplay -f S16_LE < /dev/urandom
ALSA lib pcm_dmix.c:1041:(snd_pcm_dmix_open) unable to open slave
Failed to open default device
```


TEST 2: Now we have `/opt/alsa-lib -> /opt/alsa-lib-1.1.9`, stop and restart youtube playback, then do:

```
rm -r /opt/alsa-lib
ln -sv /opt/alsa-lib-1.1.2 /opt/alsa-lib
exit

# now we try to run aplay with 1.1.2 linkeage:
aplay -f S16_LE < /dev/urandom
ALSA lib pcm_dmix.c:1041:(snd_pcm_dmix_open) unable to open slave
Failed to open default device
```

CONCLUSION: `1.1.2` and `1.1.9` versions are not able to run in parallel, with `dmix`

But this conclusion doesn't mean much, we need tests with flatpak apps too.

#### Tests with flatpak apps

At this point we already have both `alsa-lib-1.1.2` and `alsa-lib-1.1.9` installed on the Axiom host. Now we need to make sure we both version compiled inside flatpak runtime `org.freedesktop.Sdk` vesrion `19.08`. 

```
cd /home/jerry/.opt/hutches/flatpak
hutchr-launcher /bin/sh

# we will use the same folder where we have built 1.1.9
cd /home/me/Downloads/alsa-test/alsa
wget http://mirrors.tassig.com/alsa-lib/alsa-lib-1.1.2.tar.bz2
tar xf alsa-lib-1.1.2.tar.bz2

# now enter Sdk, to complile 1.1.2 library
cd /home/me/Downloads/alsa-test/alsa
mkdir alsa-install-1.1.2
cd alsa-lib-1.1.2
./configure  --prefix=/home/me/Downloads/alsa-test/alsa-install-1.1.2
make -j
make install

exit
exit
```

##### TEST 1

Running playback on Axiom host with `alsa-lib-1.1.2`

flatpak app with `alsa-lib-1.1.2` in the sandbox

```
su
rm /opt/alsa-lib
ln -sv /opt/alsa-lib-1.1.2 /opt/alsa-lib

# Now start long youtube playback

cd /home/jerry/.opt/hutches/flatpak
hutchr-launcher /bin/sh

# ensure we have 1.1.2 in the sandbox
cd /home/me/Downloads/alsa-test/

/opt/flatpak/var/lib/flatpak/runtime/org.freedesktop.Sdk/x86_64/19.08/active/files/lib/x86_64-linux-gnu/

# replace lib
rm libasound.so.2.0.0
cp /home/me/Downloads/alsa-test/alsa-install-1.1.2/lib/libasound.so.2.0.0 .

# replace configs
cd ../../share/
cp alsa/alsa.conf.d/virtual_sound_card_config.conf .
rm -rf alsa/
cp -r /home/me/Downloads/alsa-test/alsa-install-1.1.2/share/alsa .
mv virtual_sound_card_config.conf alsa/alsa.conf.d/

# now enter Sdk
flatpak run --command=sh --devel --device=all org.audacityteam.Audacity

# recompile test application, simple-playback
cp /home/me/Downloads/alsa-test/
gcc -o simple-playback simple-playback.c -lasound

# run test app
./simple-playback default < /dev/urandom
ALSA lib pcm_dmix.c:1041:(snd_pcm_dmix_open) unable to open slave
Failed to open default device

exit
exit
```

**TEST FAILED!**

##### TEST 2

Running playback on Axiom host with `alsa-lib-1.1.9`

flatpak app with `alsa-lib-1.1.2` in the sandbox

```
su
rm /opt/alsa-lib
ln -sv /opt/alsa-lib-1.1.9 /opt/alsa-lib

# Now start long youtube playback

cd /home/jerry/.opt/hutches/flatpak
hutchr-launcher /bin/sh

# we already have 1.1.2 in the sandbox

# now enter Sdk
flatpak run --command=sh --devel --device=all org.audacityteam.Audacity

# run test app
./simple-playback default < /dev/urandom

exit
exit
```

**TEST SUCCESS!**


##### TEST 3

Running playback on Axiom host with `alsa-lib-1.1.2`, 
flatpak app with `alsa-lib-1.1.9` in the sandbox

```
su
rm /opt/alsa-lib
ln -sv /opt/alsa-lib-1.1.2 /opt/alsa-lib

# Now start long youtube playback

cd /home/jerry/.opt/hutches/flatpak
hutchr-launcher /bin/sh

# ensure we have 1.1.9 in the sandbox
cd /home/me/Downloads/alsa-test/

/opt/flatpak/var/lib/flatpak/runtime/org.freedesktop.Sdk/x86_64/19.08/active/files/lib/x86_64-linux-gnu/

# replace lib
rm libasound.so.2.0.0
cp /home/me/Downloads/alsa-test/alsa-install-1.1.9/lib/libasound.so.2.0.0 .

# replace configs
cd ../../share/
cp alsa/alsa.conf.d/virtual_sound_card_config.conf .
rm -rf alsa/
cp -r /home/me/Downloads/alsa-test/alsa-install-1.1.9/share/alsa .
mkdir alsa/alsa.conf.d/
mv virtual_sound_card_config.conf alsa/alsa.conf.d/

# now enter Sdk
flatpak run --command=sh --devel --device=all org.audacityteam.Audacity

# recompile test application, simple-playback
cp /home/me/Downloads/alsa-test/
gcc -o simple-playback simple-playback.c -lasound

# run test app
./simple-playback default < /dev/urandom
ALSA lib pcm_dmix.c:1041:(snd_pcm_dmix_open) unable to open slave
Failed to open default device

exit
exit
```

**TEST FAILED!**

##### TEST 4

Running playback on Axiom host with `alsa-lib-1.1.9`, 
flatpak app with `alsa-lib-1.1.9` in the sandbox

```
su
rm /opt/alsa-lib
ln -sv /opt/alsa-lib-1.1.9 /opt/alsa-lib

cd /home/jerry/.opt/hutches/flatpak
hutchr-launcher /bin/sh

# we already have 1.1.9 in the sandbox

# now enter Sdk
flatpak run --command=sh --devel --device=all org.audacityteam.Audacity

# run test app
./simple-playback default < /dev/urandom

exit
exit
```

**TEST SUCCESS!**

#### Test summary

When `alsa-lib-1.1.2` is on the Axiom host side, flatpak alsa apps **DONT'T WORK**, regardless of the `alsa-lib` version in the sandbox

When `alsa-lib-1.1.9` is on the Axiom host side, flatpak alsa apps **WORKS FINE**, regardless of the `alsa-lib` version in the sandbox

TODO: We can do more investigation on this issue.


## How to properly compile working alsa-lib in the Sdk runtime

TODO

