# alsa in flatpak

This document explains issues with flatpak applications that uses alsa-lib as audio backend. 

Conclusions form this document are applied in `alsa-fixes.patch`

More details are given in the document `alsa flatpak issues investigation.md`


## Problems with alsa-lib in flatpak apps

First we list know issues, which shows up after detailed investigation and to give proposed solution. In next chapter we'll provide more detailed explanations about `how we came to these conclusions`


### 1. alsa configuration

`flatpak` does not mount host alsa configuration, it provides hard coded `alsa configuration` in their `runtimes`, which is pre-configured to use `pulseaudio`

`flatpak` source needs patch to propagate alsa configuration inside app sandbox



### 2. alsa-lib in the sandbox

`alsa-lib` provided in `runtimes` is compiled without support for `plugins` we use in configuration file: `asym`, `softvol`, `dmix`, `plug` and others. this makes it impossible to use our alsa configuration in the flatpak apps.

This is quite hard to understand why, alsa-lib compiles all plugins by default.

Solution to this problem is more complex, we need to override `rutime` alsa-lib with the one we have to compile on our own, with support for all required plugins.


### 3. audio group in the sandbox

`flatpak` don't provide audio group in the sandbox. Simply, before entering sandbox, `flatpak` creates `/etc/group` in the sandbox, with hard coded contents.

Soulution is simple, we patch `flatpak` to add `audio` group.


### 4. /dev/snd is missing

By default, sandboxed apps don't have access to /dev/. `flatpak` policy is to increase security. However, flatpak provides command line switch `--device=all`, which mounts host `/dev` into the application sandbox. 

`hutchr` policy is to always mount host `/dev`, so each time we run a flatpak based app, we will use `--device=all`


### 5. alsa-lib host vs guest versions and `dmix`

This is a more complex issue which needs more explanations.

#### Problem description

To show what is happening, we have to install both `alsa-lib-1.1.2` and `alsa-lib-1.1.9` on Axiom.
Then we have these situations:

If we set ongoing playback (youtube), while `/opt/alsa-lib->/opt/alsa-lib-1.1.2`, then change it to `/opt/alsa-lib->/opt/alsa-lib-1.1.9` and run another playback, then it will fail with report of being unable to use `dmix`

The same will happen in reverse case, with ongoing playback `1.1.9` and switching back to `1.1.2`

Simply, these versions are not compatible to run in parallel.

IMPORTANT NOTE: As a consequnece, updating Axiom `alsa-lib-1.1.2` to `alsa-lib-1.1.9` while we have ongoing playback, will prevent new apps to run audio, until we stop ongoing playback
 
 
#### How it reflects to flatpak apps

Axiom host side playback now uses `alsa-lib-1.1.2`, as part of Axiom root file system. This means we can't provide `alsa-lib-1.1.9` in the flatpak runtime.

Following situations were tested:

  1. Host side ongoing playback with `alsa-lib-1.1.2`, flatpak runtime has `alsa-lib-1.1.9`. flatpak audio apps **FAILS** to use `dmix`

  2. Host side ongoing playback with `alsa-lib-1.1.2`, flatpak runtime has `alsa-lib-1.1.2`. flatpak audio apps **FAILS** to use `dmix`, although we have matching libs.

  3. Host side ongoing playback with `alsa-lib-1.1.9`, flatpak runtime has `alsa-lib-1.1.9`. flatpak audio apps **SUCCESSFULY** open `dmix`, and runs fine in parallel with host playback

  4. Host side ongoing playback with `alsa-lib-1.1.9`, flatpak runtime has `alsa-lib-1.1.2`. flatpak audio apps **SUCCESSFULY** open `dmix`, even with lib vesrion mismatch.


TODO: This is strange, we need to know why host side `alsa-lib-1.1.9` is capable to run in parallell with both versions of guest side alsa libs, but host side `alsa-lib-1.1.2` is not capable of running in parallel with neither of them. It has to be something with `dmix` implemenation of shared audio buffers in `/dev/shm`

For now, seems the solution is to upgrade Axiom `alsa-lib` to `1.1.9`, if we want to allow flatpak apps to run audio concurrently with host side apps.

