# Flathub application tests report

Used labes to denote application state:

  - [READY TO PUBLISH] - is tested in details and did not show any issues
  - [WORK] - is briefly tested but needs more user tets
  - [MINOR ISSUES] - works but has known minor issues
  - [DONT'T WORK] - has issues that needs to be resoved 

Applications are being tested and sorted by `flathub` categories

[https://flathub.org/apps]



# Audio & Video

## [DONT'T WORK] Audacity - org.audacityteam.Audacity

In case we have ongoing playback on the host, audacity will fail to open dmix.
With alsa-1.1.9 and Axiom alsa config file, Ausacity will report:
```
ALSA lib pcm_dmix.c:1108:(snd_pcm_dmix_open) unable to open slave
ALSA lib pcm.c:2564:(snd_pcm_open_noupdate) Unknown PCM cards.pcm.rear
ALSA lib pcm.c:2564:(snd_pcm_open_noupdate) Unknown PCM cards.pcm.center_lfe
ALSA lib pcm.c:2564:(snd_pcm_open_noupdate) Unknown PCM cards.pcm.side
ALSA lib pcm_route.c:869:(find_matching_chmap) Found no matching channel map
ALSA lib pcm_dmix.c:1043:(snd_pcm_dmix_open) The dmix plugin supports only playback stream
ALSA lib pcm_dsnoop.c:575:(snd_pcm_dsnoop_open) The dsnoop plugin supports only capture stream
ALSA lib pcm_dmix.c:1108:(snd_pcm_dmix_open) unable to open slave
```

IMPORTANT NOTE: audacity has ipc shared, and alsa samples (open/playback) worsk fine

TODO: Audacity uses patched PortAudio v19, which has support for alsa, but unfortunately it does not support virtual alsa devices, so we are still limited to use audacity only if it is the only sound applicaton active.


## [WORK] Cinema com.github.artemanufrij.playmyvideos

Additional note: this app will crash without dbus, so if we want to test it form command line we have to manually invoke it with `dbus-launch` wrapper.

## [WORK] Clementine - org.clementine_player.Clementine

This application has one quirk: files with spaces won't work. There is nothing we can do...

## [WORK] Cozy - com.github.geigi.cozy

Looks kind of ugly with default GTK theme

## [WORK] Elisa org.kde.elisa

## [WORK] Flowblade - io.github.jliljebl.Flowblade

Not tested enough, we need to make a video/audio project, test import, workflow and export

## [WORK] Glide - net.baseart.Glide

## [WORK] Gradio de.haeckerfelix.gradio

## [WORK] LMMS - io.lmms.LMMS

User needs to change default SDL to ALSA

## [WORK] Lollipop - org.gnome.Lollypop

## [WORK] Kodi - tv.kodi.Kodi

Kodi uses SDL2 for playback, with runtime fixes we provide, sound works fine.


## [WORK] Kdenlive - org.kde.kdenlive

This application uses SDL, and for now it does not see ALSA as a valid SDL driver option.
It will show main window and error about audio related problem, once we close message window app closes. We need to manually change it's confoguration file, to point it to alsa driver.

[SOLVED] Issue 1: needs `dbus-launch` wrapper to start, which means it crashes if dbus is not present.

This was resolved with `dbus-launch`, the way we described in `Issues with Axiom flatpak hutch`, section `dbus`

[SOLVED] Issue 2: This application has issue with missing File dialog, this is solved, and described in section `xdg-desktop-portal and missing File dialog`

[SOLVED] Issue 3: Default audio setting will lead to app report failure in creating rendering window, on first start after installation. We need to add following lines into: `/home/me/.var/app/org.kde.kdenlive/config/kdenliverc`:

```
[sdl]
audio_backend=1
audiobackend=rtaudio
blakmagic_output_device=-1
```

This way we fake it, to try to use `alsa` instead of pulse, audio still fails, but at least app starts

Solution: Since we have fixed SDL2 support in flatpak runtimes, default Audio works now


## [MINOR ISSUES] Skype - com.skype.Client

Additional issue: skype don't remember user credentials, missing keyring daemon

TODO: try to use libsecret stub, the same we use for ubuntu based skype rip off

[SOLVED] Sometimes it may happen that Skype reports: `Fatal error: out of memory`


## [MINOR ISSUES] VLC - org.videolan.VLC

vlc can't disable screen saver, while playing long videos


## [MINOR ISSUES] Spotify - com.spotify.Client

Spotify works most of the time, in parallel with other active audio playbacks.

But sometimes it does not work, and reports error "Can't play this song".
Most likely it's something with alsa library, because Spotify works again when all other
active playbacks closes.

Refer to dedicated document `flatpak spotify issues.md`

Icon is empty.

[SOLVED] Sometimes it may happen that Spotify reports: `Fatal error: out of memory`

On shutdown, occassionally we can see error: `ERR: getaddrinfo failed: -3`, but app shuts done, and everything works fine.


## [MINOR ISSUES] Cumulonimbus - com.github.z.Cumulonimbus

Icon in mainscreen is empty, application works fine



## [DON'T WORK] Freetube - io.freetubeapp.FreeTube

Audio don't work, this application forces following envars:

export ALSA_CONFIG_DIR="/usr/share/alsa"
export ALSA_CONFIG_PATH="/usr/share/alsa/alsa-flatpak.conf"

In this case it's better it we make sure to override these envars, to point out into our known alsa mounted configuration

Once provided proper alsa configuration, we get these errors:

```
ALSA lib control.c:1375:(snd_ctl_open_noupdate) Invalid CTL hw:0
ALSA lib control.c:1375:(snd_ctl_open_noupdate) Invalid CTL hw:1
ALSA lib timer.c:184:(snd_timer_open_noupdate) Unknown timer hw:CLASS=3,SCLASS=0,CARD=1,DEV=7,SUBDEV=0
ALSA lib timer.c:184:(snd_timer_open_noupdate) Unknown timer hw:CLASS=3,SCLASS=0,CARD=1,DEV=7,SUBDEV=0
ALSA lib pcm_direct.c:1421:(snd1_pcm_direct_initialize_poll_fd) unable to open timer 'hw:CLASS=3,SCLASS=0,CARD=1,DEV=7,SUBDEV=0'
ALSA lib pcm_dmix.c:1192:(snd_pcm_dmix_open) unable to initialize poll_fd
ALSA lib pcm.c:2564:(snd_pcm_open_noupdate) Unknown PCM plug:default
```

This requires more investigation. Check if it has something to do with SDL (avaliable in the runtime), or simply the fact this app won't work with alsa 1.1.9? Default runtime alsa is 1.1.3.

NOTE: The same happens with Audacity, if we provide ALSA_CONFIG_PATH to Axiom config file

## [DON'T WORK] Girens for Plex

```
 Remote error from secret service: org.freedesktop.DBus.Error.ServiceUnknown: The name org.freedesktop.secrets was not provided by any .service files
Traceback (most recent call last):
  File "/app/share/girens/girens/window.py", line 156, in __screen_mapped
    self._plex = Plex(os.environ['XDG_CONFIG_HOME'], os.environ['XDG_CACHE_HOME'], self._player)
  File "/app/share/girens/girens/plex.py", line 56, in __init__
    self._token = self.get_token(self._user_uuid)
  File "/app/share/girens/girens/plex.py", line 80, in get_token
    return Secret.password_lookup_sync(Secret.Schema.new("nl.g4d.Girens", Secret.SchemaFlags.NONE, {'uuid': Secret.SchemaAttributeType.STRING}), {'uuid': uuid}, None)
gi.repository.GLib.Error: g-dbus-error-quark: The name org.freedesktop.secrets was not provided by any .service files (2)
```

## [DON'T WORK] Gnome-music - org.gnome.Music

```
XDG Music dir is not set
--- Logging error ---
Traceback (most recent call last):
  File "/app/lib/python3.7/site-packages/gnomemusic/pauseonsuspend.py", line 128, in _suspend_proxy_ready
    self._suspend_proxy = proxy.new_finish(result)
gi.repository.GLib.GError: g-io-error-quark: Error receiving data: Connection reset by peer (44)

During handling of the above exception, another exception occurred:

Traceback (most recent call last):
  File "/usr/lib/python3.7/logging/__init__.py", line 1025, in emit
    msg = self.format(record)
  File "/usr/lib/python3.7/logging/__init__.py", line 869, in format
    return fmt.format(record)
  File "/usr/lib/python3.7/logging/__init__.py", line 608, in format
    record.message = record.getMessage()
  File "/usr/lib/python3.7/logging/__init__.py", line 369, in getMessage
    msg = msg % self.args
TypeError: not all arguments converted during string formatting
Call stack:
  File "/app/bin/gnome-music", line 153, in <module>
    sys.exit(main())
  File "/app/bin/gnome-music", line 148, in main
    return run_application()
  File "/app/bin/gnome-music", line 137, in run_application
    return app.run(sys.argv)
  File "/usr/lib/python3.7/site-packages/gi/overrides/Gio.py", line 44, in run
    return Gio.Application.run(self, *args, **kwargs)
  File "/app/lib/python3.7/site-packages/gnomemusic/pauseonsuspend.py", line 131, in _suspend_proxy_ready
    "Error: Failed to contact logind daemon:", e.message)
Message: 'Error: Failed to contact logind daemon:'
Arguments: ('Error receiving data: Connection reset by peer',)
16:01:55 WARNING	XDG Music dir is not set
search source <__gi__.GrlTrackerSource object at 0x7fe67401fb40 (GrlTrackerSource at 0x5614a61da2a0)>

(org.gnome.Music:2): Grilo-WARNING **: 16:01:55.656: [dleyna] ../src/dleyna/grl-dleyna-servers-manager.c:138: Unable to fetch the list of available servers: GDBus.Error:org.freedesktop.DBus.Error.ServiceUnknown: The name com.intel.dleyna-server was not provided by any .service files
16:01:55 WARNING	Error: g-dbus-error-quark, GDBus.Error:org.freedesktop.DBus.Error.ServiceUnknown: The name org.freedesktop.Tracker1 was not provided by any .service files
```

## [DON'T WORK] Gnome Twitch - com.vinszent.GnomeTwitch

Gui loads fine, then it presents two options for player:
  * GStreamer Cario player backend
  * GStreamer OpenGL player backend

Then (with both options) Twitch crashes with:

```
[16:10:27] Message - GNOME-Twitch : {GtPlayer:1309} Opening stream 'rainbow6bravo' with quality 'source'
[16:10:32] Warning - GNOME-Twitch : {GtTwitch:335} Received unsuccessful response from url 'https://api.twitch.tv/api/channels/rainbow6bravo/access_token' with code '410' and body '{"error":"Gone","status":410,"message":"this API has been removed."}'
[16:10:32] Warning - GNOME-Twitch : {GtTwitch:593} Error getting stream access token for channel 'rainbow6bravo' because: Received unsuccessful response from url 'https://api.twitch.tv/api/channels/rainbow6bravo/access_token' with code '410' and body '{"error":"Gone","status":410,"message":"this API has been removed."
```

TODO: Try to create our Twich account, and try to login


## [DON'T WORK] GoodVibes - io.gitlab.Goodvibes

Desktop elements and icons are missing.

Audio playback fails with:

```AL lib: (EE) ALCplaybackAlsa_open: Could not open playback device 'default': No such file or directory
AL lib: (EE) ALCplaybackAlsa_open: Could not open playback device 'default': No such file or directory
```

## [DON'T WORK] Google Play Music Desktop Player - com.googleplaymusicdesktopplayer.GPMDP

TODO: We just need a google acount to test

## [DON'T WORK] gPodder - org.gpodder.gpodder

While trying to play podcast file, following error occurs:

```
Failed to call portal: GDBus.Error:org.freedesktop.DBus.Error.ServiceUnknown: The name org.freedesktop.portal.Desktop was not provided by any .service files
```

TODO


## [DON'T WORK] GSequencer - org.nongnu.gsequencer.gsequencer

Installation fails in hutchr:

`1581095093.221, FATAL ERROR: the flatpak app installation failed`

This app installation is broken, once we install it form flatpak, it repors success, but if we try to run it, it reports error:

`error: app/org.nongnu.gsequencer.gsequencer4/x86_64/master not installed`

## [DON'T WORK] Hydrogen - org.hydrogenmusic.Hydrogen

```
(E) AlsaAudioDriver::connect ALSA: cannot open audio device hw:0:Device or resource busy
(E) ::void* H2Core::alsaMidiDriver_thread(void*) Error opening ALSA sequencer: No such file or directory
(E) AlsaAudioDriver::connect error in snd_pcm_hw_params_set_period_size: Invalid argument
(E) ::void* H2Core::alsaAudioDriver_processCaller(void*) Can't set realtime scheduling for ALSA Driver
(E) Filesystem::check_permissions  is not a file
(E) Sample::load Unable to read 
(E) AlsaMidiDriver::handleQueueNote seq_handle = NULL 
(E) AlsaMidiDriver::handleQueueNoteOff seq_handle = NULL 
```

## [DON'T WORK] Karapulse - org.karapulse.Karapulse

This app starts, but shows empty screen and messge:

`Waiting for songs on: 192.168.15.120:1848`

Icon is missing



# Productivity

## [WORK] Libreoffice - org.libreoffice.LibreOffice

Taskbar icon is empty


## [DON'T WORK] Gnome Calendar - org.gnome.Calendar

Issue 1: it rewuired /etc/machine-id to be present in the flatpak hutch, but won't crash becuse of it

Issue 2: it fails to start dbus-daemon inside own sandbox, with error:
```
(process:355): flatpak-WARNING **: Failed to connect to bus: Could not connect: No such file or directory

** (process:2): CRITICAL **: 13:00:03.674: e_cal_data_model_set_timezone: assertion 'zone != NULL' failed

** (process:2): CRITICAL **: 13:00:03.676: e_cal_data_model_set_timezone: assertion 'zone != NULL' failed

(gnome-calendar:2): dzl-menu-manager-WARNING **: 13:00:03.724: Link of type "section" missing "id=". Merging will not be possible.

(gnome-calendar:2): GcalClock-WARNING **: 13:00:03.731: Error acquiring logind DBus proxy: Error receiving data: Connection reset by peer

(gnome-calendar:2): GcalManager-WARNING **: 13:00:03.731: Failed to access calendar configuration: Error spawning command line “dbus-launch --autolaunch=99e29be5eb864bddbac446e9c46f6e25 --binary-syntax --close-stderr”: Child process exited with code 1
```

Issue 3: once started with dbus-launch wrapper, it will segfault in `glib` related to time zone.

TODO: It must be something in `/etc` that we are missing.

[MINOR ISSUES] us.zoom.Zoom

Using ALSA backend, zoom is not able to play sound, dmix open will fail. It seems that zoom
access hardware alsa devices directly, and ignores Axiom alsa configuration, which is also loaded. Some investigation shows it uses `/usr/share/alsa/pcm/default.conf`, which is wrong.

Workaround is to use flatpak provided pulseaudio.  


# Games

## [WORK] Aqueducts - com.endlessnetwork.aqueducts


## [WORK] Aisleriot Solitaire - org.gnome.Aisleriot

## [WORK] Albion Online - com.albiononline.AlbionOnline

Icon is missing while downloading updates, but once game starts, icon is fine
Audio works
Seems there is a problem to connect to their dedicated server

## [WORK] Armagetron - org.armagetronad.ArmagetronAdvanced

Works, after we added support for org.freedesktop.Platform 1.6 runitme.

## [WORK] Astro Menace - com.viewizard.AstroMenace

## [WORK] Atomic Tanks - net.sourceforge.atanks

## [WORK] mGBA - io.mgba.mGBA

With SDL2 runtime fixes, audio works fine

## [] O.A.D - com.play0ad.zeroad

Audio fails, seems like it's explicitly expecting OSS:
```
AL lib: (EE) ALCplaybackOSS_open: Could not open /dev/dsp: No such file or directory
ERROR: Sound: AlcInit failed, m_Device=0x0 m_Context=0x0 dev_name=OpenAL Soft err=a004
```

## [DON'T WORK] Athenaeum - com.gitlab.librebob.Athenaeum

```
Traceback (most recent call last):
  File "/app/lib/python3.7/site-packages/athenaeum-1.2.0-py3.7.egg/athenaeum/loader.py", line 433, in loadListData
    self.loadAppstream(process=True)
  File "/app/lib/python3.7/site-packages/athenaeum-1.2.0-py3.7.egg/athenaeum/loader.py", line 74, in loadAppstream
    stream.from_file(self._appsteamPath)
  File "/app/lib/python3.7/site-packages/athenaeum-1.2.0-py3.7.egg/athenaeum/appstream/store.py", line 64, in from_file
    with gzip.open(filename, 'rb') as f:
  File "/usr/lib/python3.7/gzip.py", line 53, in open
    binary_file = GzipFile(filename, gz_mode, compresslevel)
  File "/usr/lib/python3.7/gzip.py", line 163, in __init__
    fileobj = self.myfileobj = builtins.open(filename, mode or 'rb')
FileNotFoundError: [Errno 2] No such file or directory: '/home/me/.var/app/com.gitlab.librebob.Athenaeum/data/flatpak/appstream/flathub/x86_64/active/appstream.xml.gz'
```

# Graphics & Photography

## [WORK] Darktable - org.darktable.Darktable

Axiom - works, complains about /etc/machine-id and dbus, but won't crash

Mainscren icon is missing

Ubuntu - the same complaints, icon is fine

## [WORK] Gimp - org.gimp.GIMP


# Browsers

## [MINOR ISSUES] Firefox - org.mozilla.firefox

[SOLVED] Sound works with pulseaudio integrated as a hutch inside flatpak hutch

[SOLVED] Sometimes it may happen that Firefox reports: `Fatal error: out of memory`

Some videos will play with obvious frame skip, some won't. Seems some video formats lacks hardware support.

Sound glitches, while one video is playing, and user continues to browse in other tab. It is likely to happen with just bworsing web pages, but seems playing other videos in parallel, makes this issue worse.

File chooser does not work (gitlab account), and it turns out it tries to access host file chooser via xdg desktop portal. This is visible from flatpak `portal.log`, with `XDG-DESKTOP-PORTAL-AXIOM: FileChooser: OpenFile call` entry.

Trying to add `export GTK_USE_PORTAL=0` don't mitigate this issue. There has to be other way around to disable FileChooser portal.

