# Flatpak

## [SOLVED] /tmp storage space 

By default flatpak and ostree uses /tmp, and wants a big /tmp. This generates an error:

```
Error: Not enough disk space to complete this operation
error: Failed to install org.gnome.Platform: While pulling runtime/org.gnome.Platform/x86_64/3.34 from remote # flathub: Writing content object: min-free-space-size 500MB would be exceeded, at least 2.0 kB reques
```

But this error does not occur as root. So what is ostree doing when root vs normal user?

This is solved by making symlink `/opt/flatpak/var -> /home/varflatpak`. That's the place where flatpak will keep bulky runtimes and other stuff which requires GB's of free space.

Also, this is not an issue with flatpak hutch, internal /opt is rw.


## [SOLVED] gsettings-desktop-schemas, XDG_DATA_DIRS and gtk themes

befoure using `flatpak` we need export to export `XDG_DATA_DIRS=/opt/gsettings-desktop-schemas-3.20.0/share` . I guess it's fine, and not really an issue.

Now we give more explanations on how `flapak` uses this envar. The only place in flatpak source code which depends on `gsettings-desktop-schemas` is when flatpak tries to get host active theme. So flatpak wrongly presumes we are running in `GNOME` environment, we have `gtk3` and it is not true for Axiom flatpak hutch. 

Axiom flatpak hutch has gtk2, doesn't have `GNOME` and theme detection is not supported unsing `gsettings-desktop-schemas`. So basically, it's useless under the axiom flatpak hutch. It will always return `Adwaita`, because it's default gtk3 theme. The only reason flatpak is doing this way is because it's trying to match host theme, if possible. But this is wrong anyway.

TODO: We can safely and easily patch flatpak sources, not to use
`gsettings-desktop-schemas` at all, because it's useless and don't serve any purpose under Axiom flatpak hutch. Instead we can simply return `Adwaita` theme as string.

While installing new application, flatpak will try to get host theme (which will always be Adwaita) and then try to download additional `Adwaita` theme runtime (org.kde.KStyle.Adwaita). Since most flatpak apps are GTK3, this will work just fine with default `Adwaita`. TODO: This seems to suggest that if an app is not GTK3, it will not work just fine.

See more details in the `how flatpak detects host resources.md` document


## dbus [SOLVED]

Applications may require dbus explicitly, and some of them won't run if they don't find dbus in `/run/user/uid/bus`. For example `org.kde.kdenlive`.

First we need to provide `dbus` binaries in flatpak hutch, also with `expat` dependency. This is the job for flatpak hutch builder script.

To ensure every app see `dbus` socket, we can run apps with `dbus-launch` wrapper, which will start `dbus-daemon` and set appropriate env variables `DBUS_SESSION_BUS_ADDRESS`, and then executes target program. In `run.sh` we can use it this way:

```sh
XDG_DATA_DIRS=/opt/gsettings-desktop-schemas-3.20.0/share dbus-launch /bin/flatpak $@
```

More details about dbus-launch: `https://dbus.freedesktop.org/doc/dbus-launch.1.html`


## [SOLVED] /etc/machine-id 

Some apps may require `/etc/machine-id`, but up to now we haven't seen any of them crash if they don't find it. This is required mostly by apps trying to use `ibus`.

TODO: hutchr should generate a machine-id at installation of flatpak hutch


## [SOLVED] XDG_RUNTIME_DIR issue

This issues happens while running flatpak hutch on Ubuntu.

At first attempt to run a flatpak application, flatpak will fail with following error:

`bwrap: Can't find source path`

Investigation with bwrap sources shows up that flatpak feeds one empty path argument, to `--ro-bind` operation. So the issue was with flatpak, not bwrap.

Flatpak sources investigation shows that at one point, flatpak calls `flatpak_get_real_xdg_runtime_dir`, which returns an epmty string. This is in `common/flatpak-utils.c`.

```c
char *
flatpak_get_real_xdg_runtime_dir (void)
{
  return realpath (g_get_user_runtime_dir (), NULL);
}
```

According to glib manual, `g_get_user_runtime_dir`, tries to read `XDG_RUNTIME_DIR`, which is defined on Ubuntu, as `XDG_RUNTIME_DIR=/run/user/1000`. Since such folder don't exist inside flatpak hutch, realpath returns NULL.

This is a bug, because flatpak allows this to be passed to bwrap. 

According to glib manual, with `g_get_user_runtime_dir`, if `XDG_RUNTIME_DIR` is not set, then it returns what `g_get_user_cache_dir()` would return.

Actually, flatpak needs patch, in case `XDG_RUNTIME_DIR` exists and point to non existing path, we have to test what `readlink` retunrs, and if it's NULL, we have to call `g_get_user_cache_dir()`, as this is the same behavior, if `XDG_RUNTIME_DIR` was not set.

This patch is implemented in `xdg_runtime_dir_fix.patch`

TODO: this patch seems wrong, this condition should not hold: `XDG_RUNTIME_DIR` exists and point to non existing path
      if such condition hols, then of course there can be a bug. In other words, buggy environment variables can lead to crash the application. This is normal behavior.
      What is needed instead is a sanitization of the environment variables.
      There can be many environment variables that could be wrong in the context of hutchr. So hutchr should not give these environment variables to flatpak.
      Other option is hutchr should bind-mount the /run/user/1000


## [SOLVED] xdg-desktop-portal and missing File dialog

Some applications like `kdenlive` and `shotcut` will start, but File dialog won't work. By clicking `Open` or `Save`, kdenlive do nothing, and shotcut freeze. 

This issue happens in Axiom hutch, things works with native flatpak ubuntu installation. This was good so we could compare what was the difference:

  - running Ununtu and flatpak installation with `apt install` is where things works fine
  - runninf Ubuntu and Axiom flatpak hutch with `hutchr` is where issue aride

Some investigation shows that flatpak uses `xdg-desktop-portal` to allow applications to run some operations outside sandbox, on the host, like opening File dialog, opening uri/url, using printer, etc.


Basically, `xdg-desktop-portal` is software which runs on the host, and provide services to flatpak, and sandboxed applications, via `dbus`.

GTK3 and QT5 frameworks has transparent support for `xdg-desktop-portal`, so applications don't have to access it directly. This allows applications to use host side `native` File dialogs (alos Font and Color dialog).

Both `kdenlive` and `shotcut` are qt5 applications, and they fail to access `xdg-desktop-portal` on the host side, but the question was, why don't they fallback to normal QT file dialog?

Further investigation shows that gtk3 and qt5 differs in the way they use native dialogs:

GTK3 has normal `GtkFileChooserDialog` and native `GtkFileChooserNative`. I have compiled test program, to just show `GtkFileChooserNative`. Such program works both with native Ubuntu flatpak installation, and with Axiom flatpak hutch (although it compalins for missing dbus). So GTK3 properly falls back to normal dialog, when native dialog can't be created.

QT5 uses `QFileDialog` Class, and by default it will try to run native dialog. This can be prevented with `DontUseNativeDialog` property, but for precompiled apps like `kdenlive` we can't expect it. So I have compiled test program to run one file dialog, and it works under native Ubuntu flatpak installation, and fails under Axiom flatpak hutch, the same way `kdenlive` and `shotcut` does. Clearly QT5 has an issue, when native dialog is not available. 

Quick workaround was to set `QT_QPA_PLATFORMTHEME=gtk3` which will override `QFileDialog` default wish to use native dialog, and will enforce GTK3, which is available under sandboxed application.

Links that helped this investigation:

  - `https://github.com/flatpak/flatpak/wiki/Portals`
  - `https://bbs.archlinux.org/viewtopic.php?id=238344`
  - `https://kb.froglogic.com/squish/qt/howto/automating-native-file-dialogs/#general-solution-1---automate-the-dialogs-via-nativetype`
  - `https://developer.gnome.org/gtk3/stable/gtk3-GtkFileChooserNative.html#gtk-file-chooser-native-new`

TODO: Add more explanations about debugging procedure


Now both `kdenlive` and `shotcut` will show File dialog without issues.

TODO: Better solution is to provide `xgd-desktop-portal` in Axiom hutch. It allows other useful integration features. For this we need to compile `xgd-desktop-portal`, which is easy, and `xgd-desktop-portal-gtk`which requires GTK3 and may be troublesom to bring in on Axiom.

TODO: get more knowledge on how `xgd-desktop-portal` is implemented and used by `flatpak`


## [SOLVED] Apps won'r run with 'hutchr appID' and runs if invoked form command line

With some apps, like Spotify Atom or Skype, if you run via hutchr directly ("./hutchr APPID"), it doesn't work. If you run by first running /bin/sh (by modifying run.sh, it works). So there is some sort of tricky thing going on.

TODO: explain


## Graphic related issues

### openh264 issue

`org.freedesktop.Platform.openh264` runtime fails to install.

### [SOLVED] GLX 

  * blender: tries to access "/usr/lib/x86_64-linux-gnu/libGLX_indirect.so.0": openat(AT_FDCWD, "/usr/lib/x86_64-linux-gnu/libGLX_indirect.so.0", O_RDONLY|O_CLOEXEC) = -1 ENOENT (No such file or directory)
  * shotcut - the same
  * kdenlive - the sane

So i manually added this file "/usr/lib/x86_64-linux-gnu/libGLX_indirect.so.0", but it still complains with the same error. So flatpak namespaces are more tricky than hutchr ones, and i couldn't see straight away how the filesystem is defined. In any case, the application should see the GLX driver file, it's abnormal that it doesn't see it.

What happens is explained on https://bugzilla.redhat.com/show_bug.cgi?id=1427174#c31 , comment 31.
Since X server 1.19, the app using openGL wants to send openGL commands to the X server via GLX (which is the purpose of GLX), and to do that it loads a GLX library. This library, in turn, queries the X server to know what is the vendor of the graphic card (the openGL commands will depend on that). Then it loads the relevant vendor-specific GLX library. When the server is 1.18, it does not support this extension, and the app will fallback on some other libraries. The name resolution of these libraries is broken on the rootfs of the app.

This can be fixed with `__GLX_VENDOR_LIBRARY_NAME=mesa` or by `LD_LIBRARY_PATH` so `libGLX_indirect` can be found.

Hutchr solves this issue by adding this envar, in case we run flatpak application. Also, this fix has to check Xorg version.


## [SOLVED] flatpak application installation in parallel fails

with flatpak-1.4.3 there is an issue with installing applications in parallel. It happens when two applications use same runtimes, and tries to install this runtime at the same time. Internally, flatpak downloads runtime in some temportary folder, and once it's downloaded, it copies it to the destination. If runtime was not installed when new installation begins, app will try to install it. But if someone has already done it (other app installed in parallel), flatpak will report error and terminate installation.

This issue was resolved starting form flatpak-1.8.1. Tests were done to prove it is the case. Test script `parallel-install-test.sh` shows this behavior, where both applications try to install `org.freedesktop.Platform` version `19.08`

```sh
flatpak install --assumeyes org.mozilla.firefox &
flatpak install --assumeyes com.skype.Client &
```

With flatpak-1.4.3, only one app will get installed, other will fail. With flatpak-1.8.2, both applications will be installed.

Similar, more obvious test was done where we try to install two same runtimes at the same time:

```sh
flatpak install --assumeyes org.freedesktop.Platform/x86_64/19.08 &
flatpak install --assumeyes org.freedesktop.Platform/x86_64/19.08 &
```

Result is the same: flatpak-1.4.3 reports error, flatpak-1.8.2 don't report any error.


## Audio related issues

`alsa` and `sdl` issues are described in separate documents:
  - `alsa flatpak issues.md`
  - `sdl2-flatpak-issues.md`

We konw OSS does not work, but hopefully we wont have any app using OSS as the only sound layer.

### Pulseaudio

* firefox sound works only with pulseaudio

TODO: provide pulseaudio hutch inside flatpak hutch 


### Occasional error while trying to intall app

Sometimes, not repeatable, hutchr reports `FATAL ERROR: the flatpak app installation failed`


## Behavior of flatpak

* installation and running are done separately. Installation can be done as normal user

* when an application is run as jerry, it writes in ~/.var/ .

* installing a few apps takes 10G of data, but this is related to runtimes size. Once most frequent runtimes were installed, apps takes few tens of MB of space.

* flatpak runtimes, apps and all other stuff get's installed in `/opt/flatpak/var`

* user specific application stuff get's installed in `~/,var`










