# How Flatpak detect host side resources, to match donloading runtimes

`flatpak` tries to detect following host side resources:

  - gl drivers
  - does host has intel drivers
  - active gtk theme
  - XDG_CURRENT_DESKTOP

These actions can be observed in flatpak sources, `common/flatpak-utils.c`. One important function is `flatpak_extension_matches_reason`, which tries to match runtime extensis, by examining host contents.

## gl drivers

flatpak search for gl dirvers in: 
  * env `FLATPAK_GL_DRIVERS`
  * `/sys/module/nvidia/version`

If no drivers were found, it adds `default` and `host` to the list, which ends up using `org.freedesktop.Platform.GL.default`

This is fine, hutchr share `/sys` and in case system has nvidia gl hardware, it will be picked up.


## does host has intel drivers?

flatpak search `"/sys/module/i915`, and in case it was found, it downloads `org.freedesktop.Platform.VAAPI.Intel` and `org.freedesktop.Platform.openh264`


## active gtk theme

`flatpak` tries to get current host `gtk theme`, using `gsettings-desktop-schemas`. In `common/flatpak-utils.c` it executes `flatpak_get_gtk_theme` which use Gsettings to get current theme. 

This is the only reason we need `XDG_DATA_DIRS=/opt/gsettings-desktop-schemas-3.20.0/share`, otherwise it will report glib error and missing schemas.

Since Axiom runs gtk2 and does not have GNOME, `gsettings-desktop-schemas` simply returns default gtk3 theme `Adwaita`. Then flatpak downloads appropriate runtime.


## XDG_CURRENT_DESKTOP

`flatpak` parses env variable `XDG_CURRENT_DESKTOP` to find additional runtimes. On Axiom it's skipped, on Ubuntu it's `ubuntu:GNOME` so it download additional runtimes:

  - org.kde.PlatformTheme.QGnomePlatform.Sources
  - org.kde.PlatformTheme.QGnomePlatform
  - org.kde.WaylandDecorations.QGnomePlatform-decoration
  - org.kde.WaylandDecorations.QGnomePlatform-decoration.Sources

This seems to be wrong, we don't provide Waylands
