# Flatpak patch to add app installation progress support for mainscreen

Typical hutchr application installation will report download progress via dedicated mainscreen socket. This is done by `hutchr` in the moment of downloading application package.

To do the same with `flatpak` applications, we need to patch flatpak sources, and add writing progress information in the same mainscreen socket. `flatpak` already reports installation procress in command line.

The issue is, total installation progress is not trivial. With an app, flatpak needs to install various runtimes and dependencies, and we have several possible cases:

  - if nothing is yet installed, flatpak will install all runtimes and then application
  - if all runtimes are installed, flatpak will install only application
  - if some runtimes are missing, flatpak will install them and then application

IMPORTANT NOTE: This patch uses percentages calculted by flatpak, rather than total size in bytes. This is done because runtimes sometimes are being downloaded partialy. Reading total size of a compoment does not guarantee flatpak will download whole compoment. Percentage report is accurate. 

Example of how this patch works. Let's say we app installation requires 6 components to be downloaded. We presume all 6 components are 100%. Flatpak reports percentage of a current component, and we simply recalculate total percentage, knowing how many components will be downloaded in total.


## How flatpak does installation job?

Roughly it uses `FlatpakTransaction` object to do whole job. It will hold all data related to installation process, with all required runtime components information, sizes and other data.

`FlatpakTransaction` will be initialized, and then it `flatpak` will call it's `run` function, to do installation process. Somewhere inside this function we shall calculate total size of all components, and overall progress in %


`FlatpakTransaction` is a base object, and we have two types of derived objects:

  - `FlatpakQuietTransaction` - used when we choose `--noninteractive` mode of installation
  - `FlatpakCliTransaction` - used to show all relevan information in command line, including progress

IMPORTANT NOTE: we have to use force flatpak to use `FlatpakCliTransaction` because this object contains whole infrastructure to report progress.

Each derived object will provide it's own `run` function.

## FlatpakTransaction type

Type definition is done via GDK macros, in `flatpak-transaction.h`:

```
FLATPAK_EXTERN
G_DECLARE_DERIVABLE_TYPE (FlatpakTransaction, flatpak_transaction, FLATPAK, TRANSACTION, GObject)

struct _FlatpakTransactionClass
{
...
  gboolean (*run)            (FlatpakTransaction *transaction,
                              GCancellable       *cancellable,
                              GError            **error);
```

### Transaction run functions

`FlatpakQuietTransaction` define `flatpak_quiet_transaction_run` in `flatpak-quiet-transaction.c`
At first glance it does not provide progress information facilities.


`FlatpakCliTransaction` define `flatpak_cli_transaction_run` in `flatpak-cli-transaction.c`. This is the proper place for a patch. 

NOTE: We can tell hutchr to use `flatpak install --assumeyes appID`, so     `flatpak_cli_transaction_run` will be called but no user input will be required. In this case we have progress information available.






