# Flatpak patch to replace runtime or application libraries/files with versions we provide

This patch provides a way to alter runtime and application contents, with contents we provide. 

For example, one issue we have with flatpak and Axiom host is: flatpak insists on `pulseaudio` to exist on the host, and Axiom host provides only `alsa` as audio backend. Flatpak runtimes provides `alsa` too, but it was compiled without all essential plugins, used by Axiom configuration, like `dmix`, `softvol`, `plug` and many other. We have no other choice than to recompile `alsa` in flatpak development runtime environment, and to replace original runtime version, with the one which meets Axiom requirements. 

Similar situation is with `SDL2`, flatpak runtime provides version which has no `alsa` backend support. 

For more details on how we rebuild these libraries, look at `ports` repository, in:
  - `packages/extended/flatpak/runtime fixes`
  - `packages/extended/flatpak/application fixes`


Some important definitions:

`runtime fixes` is the folder where we provide fixed files/folder/libraries, and is located in `~/.opt/hutches/flatpak/filesystem layout//opt/flatpak/runtime fixes`

`runtime installation path` is the folder where flatpak keep runtimes, and all original files/folder/libraries are there. Location is `~/.opt/hutches/flatpak/filesystem layout//opt/flatpak/var/lib/flatpak/runtime`

`application fixes` is the folder where we provide fixed files/folder/libraries, and is located in `~/.opt/hutches/flatpak/filesystem layout//opt/flatpak/application fixes`

`application installation path` is the folder where flatpak keep installe applications, and all original files/folder/libraries are there. Location is `~/.opt/hutches/flatpak/filesystem layout//opt/flatpak/var/lib/flatpak/app`

`sandbox app mount path` is the path in the flatpak app sandbox, where fixed files will be bind mounter, eddecitevly replacing original files. it will be something like `/usr/lib/x86_64-linux-gnu` and similar.


## Runtime fixes

Simplified `runtime fixes` workflow:

  1) we check contents of `runtime fixes` folder
  2) we check original file existance in `runtime installation path`
  3) only if original file exists, we mount `runtime fixes` files/folders/libraries into `sandbox app mount path`, by using `bwrap` calls

IMPORTANT: If original files/folder/libraries are missing in step 2), `bwrap` will crash, because it tries to create missing file before bind mounting. Since flatpak always mount runtimes read-only, this operation won't be allowed, and flatpak app won't start. We need to avoid this situation


First thing done by this patch is to check if flapak installation has `runtime fixes` folder, and if not, to run unmodified.

In case we have such folers, we call `flatpak_run_add_runtime_fixes_args` which does all the job to add bwrap arguments, according to `runtime fixes` contents.


# alsa and SDL2 patch goal and description

Main goal is to replace wrongly compiled runtime `alsa` and `SDL2` libraries, with the correct one we provide. Note that we provide also 32-bit libraries for runtimes that has 32-bit extensions.

These are 3 cases we need to cover:

  1. Production case, where APP_ID is appliation ID, and we invoke flatpak via hutchr
  2. Debug case when we use --devel flag, and APP_ID is application ID, which forces Sdk runtime to load. This is important for app troubleshooting, when we need `strace`, `gdb` to debug troublesome application
  3. Debug case when we use APP_ID=RUNTIME/VERS, where we explicitly start shell in a given runtime, for test purposes

Simplified procedure to cover these cases:

  1. Check runtime if it has 32-bit extensions, and get 32-bit libs mount point, by looking into runtime metafile
  2. Determine runtime 64-bit mount point
  3. In case we have started application, check if it has additional 32-bit runtime, and apply additional fixes, for 32-bit libs only


## Special case - flatpak runtime updates

There is one special case for which we provide workaround. Flatpak runtimes are being updated, and at one point, they may provide newer versions of libs. But in `runtime fixes` we have previous version of this library, and checking original file existance in `runtime installation path` will fail. We could leave it unmounted, but it will lead to unusable audio. We had this situation with `org.freedesktop.Platform//19.08`, when flatpak developers decided to update SDL2 library, form version 10 to verion 12.

Situation, before update, in `runtime installation path`, in `org.freedesktop.Platform/x86_64/19.08/active/files/lib/x86_64-linux-gnu`:

`libSDL2-2.0.so.0 -> libSDL2-2.0.so.0.10.0`

After update we will have: `libSDL2-2.0.so.0 -> libSDL2-2.0.so.0.12.0`

We don't control updates, they may happen anytime. Before we provide new fixed library, we apply workaround. Simply, use library we provide in `runtime fixes` and bind mount over new library. 

To do so, we provide `find_updated_library_name_form_current`, which uses existing library name, extract symbolic link name (it's soname), read it, and return new library name, which we will overwrite.

We rely on backward compatibility. If `soname` changes, backward compatibility will be broken, and in this case we don't mout fixes, but have to provide new fixed library soon as possible.


# alsa and SDL2 patch operation

## Global vars

With global var, we get access to flatpak internal data, we need for our patch:

  *   rf_app_ref - full application reference in format TYPE/NAME/ARCH/VERSION
  *   rf_runtime_ref - full runtime reference in format TYPE/NAME/ARCH/VERSION
  *   rf_app_metakey - pointer to application metafile, used to read data form it
  *   rf_runtime_metakey - pointer to runtime metafile, used to read data form it

Using them, we can read runtime and app `metadata` contents, so we can determine if we use `32-bit` extension, and to check in which sandboxed folder fixes will be mounted. Applications uses `/app`, while if we just run runtime, it uses `/usr`


## mount points where we mount fixed libraries

For a given app/runtime, patch has to find if we provide fixes for this runtime, by looking into `runtime fixes` folser, trying to find matching runtime. Procedure is the same for `alsa` and `SDL2`, we explain `alsa` case.

### x86_64

It checks for `x86_64` version of libraries, get full library name form `runtime fixes/runtie/version/x86_64/alsa/lib/` and finds appropriate path in runtime, to mount it `mount_point_x86_64`. This is added to `bwrap` args

### i386

It checks for `x86_64` version of libraries, get full library name form `runtime fixes/runtie/version/i686/alsa/lib/`and finds appropriate path in runtime, to mount it `mount_point_i386`. This is added to `bwrap` args


## Application fixes

appID is flatpak application full name, for example `com.skype.Client`

Simplified `application fixes` workflow:

  1. check if `application fixes` exist, in `/opt/flatpak/`
  2. check if it has folder names by appID we are starting
  3. recursively list all the folders and files in "appliaction fixes/appId"
  4. for each found file, check if such file exists in appID flatpak installation folder
  5. then mount all matching files into sandboxed /app folder

Key function in the code, that implements this workflow is: `flatpak_run_add_application_fixes_args`.

TODO: add more explanations and an example

# Remarks

Patch was written to support replacing any kind of file in flatpak runtimes and applications. In case of runtimes, for now we just remount one library file, but in case we have to replace all files form some folder in `runtime fixes`, patch provides aux function `find_files_with_matching_pattern`. 

One other important remark is: If we just run shell in a Sdk runtime, patch will aslo mount corrext `includes` and `*.pc` file, so we can compile any app or test program, against the corrected library we provide. This is important for testing and troubleshooting.

We also provide test suite for `alsa` and `SDL2`, in `ports/packages/extended/flatpak/"runtime fixes/audio fixes tests"`, and these tests relies on the previous feature.

To see more detailed patch debug inforamtion, run `flatpak` with `-v` option. For example, if we want to troubleshoot Steam, we can do it this way:

```sh
cd /home/jerry/.opt/hutches/flatpak
hutchr run /bin/sh

flatpak run -v --command=sh --filesystem=/home/me/ --device=all --share=ipc  --env=ALSA_CONFIG_DIR= --env=ALSA_CONFIG_PATH= --env=SDL_AUDIODRIVER=alsa --env=QT_QPA_PLATFORMTHEME=gtk3 com.valvesoftware.Steam
```

In case of applications, we provide recursive was to find all fixes, using `find_rec_all_files`, and mount all of them in application sandbox. 
