#!/bin/bash

set -e

# This is the script to test ALSA and SDL2 simple palyback in flatpak runtime sandbox
# It uses TEST_SOUND_FILE and TEST_SHARED_FOLDER envars.

CC_64=gcc
CC_32=/usr/lib/sdk/toolchain-i386/bin/i686-unknown-linux-gnu-gcc

function run_alsa_tests()
{
	echo "compiling opem-pcm-device...."
	$CC -o open-pcm-device open-pcm-device.c -lasound
	file open-pcm-device
	
	echo "running opem-pcm-device with defaulf device"
	./open-pcm-device default
	rm open-pcm-device
	
	echo "compiling simple-playback...."
	$CC -o  simple-playback simple-playback.c -lasound
	file simple-playback
	
	echo "running simple-playback with defaulf device and test audio file"
	./simple-playback default < ../$TEST_SOUND_FILE
	rm simple-playback
	echo ""
	echo ""
}

function run_sdl2_tests()
{
	echo "compiling sdl2_test"
	$CC -o sdl2_test sdl2_audio_api.c sdl2_test.c -lSDL2
	file sdl2_test

	echo "running sdl2_test with test audio file"
	./sdl2_test ../$TEST_SOUND_FILE
	rm sdl2_test
	echo ""
	echo ""
}

# NOTE: toolchains are available only in Skd runtimes
#       anyawy we do test if compilers are available and work on a simple test file
#       only 3 runtimes has 32-bit lib support:
#          org.freedesktop.Sdk//19.08
#          org.gnome.Sdk//3.34
#          org.gnome.Sdk//3.36
function is_compiler_available ()
{
	cat << EOF > hello.c
#include <stdio.h>
int main (void) {
	printf ("Hello World\n");
	return 0;
}
EOF

# NOTE: we pass compiler path as the first argument
$1 -o hello hello.c > /dev/null 2>&1 || true
if [ -f "hello" ]; then
	COMPILER_AVAILABLE=yes
else
	COMPILER_AVAILABLE=no
fi
rm -f hello hello.c

#NOTE: we can use return in the same script where we use -e, so we use global var
}

echo "BLAAAAAAAAAAAAAAAAAAAAA: $(pwd)"

# Check and run 64-bit alsa test

cd "alsa tests"
echo ""
echo "######  ALSA: 64-bit test: #####"
is_compiler_available $CC_64
if [ "$COMPILER_AVAILABLE" = "no" ]; then
   echo "Compiler not available: [$CC_64]"
else
	export CC=$CC_64
	run_alsa_tests
fi

# Check and run 32-bit alsa test

echo ""
echo "######  ALSA: 32-bit test: #####"
is_compiler_available $CC_32
if [ "$COMPILER_AVAILABLE" = "no" ]; then
   echo "Compiler not available: [$CC_32]"
else
	export CC=$CC_32
	run_alsa_tests
fi

cd ../

# Check and run 64-bit sdl2 test

cd "sdl2 tests"
echo ""
echo "######  SDL2: 64-bit test: #####"
is_compiler_available $CC_64
if [ "$COMPILER_AVAILABLE" = "no" ]; then
   echo "Compiler not available: [$CC_64]"
else
	export CC=$CC_64
	run_sdl2_tests
fi

# Check and run 32-bit sdl2 test

echo ""
echo "######  SDL2: 32-bit test: #####"
is_compiler_available $CC_32
if [ "$COMPILER_AVAILABLE" = "no" ]; then
   echo "Compiler not available: [$CC_32]"
else
	export CC=$CC_32
	run_sdl2_tests
fi
