# How to test audio fixes

At the moment, we provide custom built:
 
  - `alsa-lib-1.1.9` because runtime version was compiled without all essential plugins
  - `SDL2-2.0.N` because it was compiled without alsa support (N=version)

For the purpose of testing, we provide simple playback code samples, wich we need to compile and run in a flatpak runtime.

The goal iof this test is to prove we can run flatpak audio applications in parallel with ongoing Axiom host playback.

## Pre-requisites

  - alsa-lib 1.1.9 on the Axiom host
  - test folder name `/home/jerry/Downloads/"flatpak audio tests"`, shared between flatpak hutch and runtimes under test
  - `test.wav` audio test file name


## Create shared folder on the host, copy test suite and test wav file

```sh
# NOTE: we have to use path which will be mounted inside flatpak hutch (Downloads for example)

mkdir /home/jerry/Downloads/"flatpak audio tests"  
cp -r * /home/jerry/Downloads/"flatpak audio tests"

# we don't provide test sound file, download something form the web and name it test.wav
cp test.wav /home/jerry/Downloads/"flatpak audio tests"
```


## Install flatpak hutch on Axiom host 
```
hutchr flatpak
```

## Install all runtimes, 32-bit extensions and 32-bit toolchain
```
cd /home/jerry/.opt/hutches/flatpak
hutchr run /bin/sh

# Inside flatpak hutch
export XDG_DATA_DIRS=/opt/gsettings-desktop-schemas-3.20.0/share

# Install flatpak runtimes (all, even the one which support has ended)
flatpak install --assumeyes org.freedesktop.Sdk//19.08
flatpak install --assumeyes org.freedesktop.Sdk//18.08
flatpak install --assumeyes org.freedesktop.Sdk//1.6
flatpak install --assumeyes org.gnome.Sdk//3.26
flatpak install --assumeyes org.gnome.Sdk//3.28
flatpak install --assumeyes org.gnome.Sdk//3.30
flatpak install --assumeyes org.gnome.Sdk//3.32
flatpak install --assumeyes org.gnome.Sdk//3.34
flatpak install --assumeyes org.gnome.Sdk//3.36
flatpak install --assumeyes org.kde.Sdk//5.9
flatpak install --assumeyes org.kde.Sdk//5.10
flatpak install --assumeyes org.kde.Sdk//5.11
flatpak install --assumeyes org.kde.Sdk//5.12
flatpak install --assumeyes org.kde.Sdk//5.13
flatpak install --assumeyes org.kde.Sdk//5.14

# Install 32-bit extensions, for runtimes that supports them
flatpak install --assumeyes org.freedesktop.Sdk.Compat.i386//19.08
flatpak install --assumeyes org.gnome.Sdk.Compat.i386//3.34
flatpak install --assumeyes org.gnome.Sdk.Compat.i386//3.36
flatpak install --assumeyes org.freedesktop.Sdk.Extension.toolchain-i386//19.08
exit
```

## Run long playback on Axiom host

Use Tassig Internet and some long youtube video

## Run tests

NOTE: To run tests we need to be inside the flatpak hutch.

NOTE: Inside flatpak hutch, home folder is "/home/me"

```sh
cd /home/jerry/.opt/hutches/flatpak
hutchr run /bin/sh

# use the same test shared dir we created above 
cd /home/me/Downloads/"flatpak audio tests"

./"run audio test in all flatpak runtimes.sh"
```

Test will list all available runtimes, run ALSA/SDL2 playback tests
