#!/bin/sh

# This script runs audio test program, for all listed flatpak runtimes.
# It is intended to run inside flatpak hutch
#
# We presume all runtimes are installed, their Compat.i386 extensions and 32-bit toolchain
# 

TEST_SHARED_FOLDER=/home/me/Downloads/"flatpak audio tests"
AUDIO_TEST_PROGRAM="audio fixes test.sh"
TEST_SOUND_FILE=test.wav

RUNTIMES="org.freedesktop.Sdk//19.08 
          org.freedesktop.Sdk//18.08
          org.freedesktop.Sdk//1.6
          org.gnome.Sdk//3.26
          org.gnome.Sdk//3.28
          org.gnome.Sdk//3.30
          org.gnome.Sdk//3.32
          org.gnome.Sdk//3.34
          org.gnome.Sdk//3.36
          org.kde.Sdk//5.9
          org.kde.Sdk//5.10
          org.kde.Sdk//5.11
          org.kde.Sdk//5.12
          org.kde.Sdk//5.13
          org.kde.Sdk//5.14"

if [ ! -f $TEST_SOUND_FILE ]; then
	echo "Test sound file is missing, provde one, and define TEST_SOUND_FILE envar"
	exit
fi

for RUNTIME in $RUNTIMES
do
    # Explanations:
    #   - v - print debug info (-vv for more verbose)
    #   --devel - forces Sdk version of runtime
    #   --cwd - run command in this folder
    #   --command - command to run in runtime/app
    #   --device=all - share complete host /dev folder
    #   --share=ipc - allow sandboxed processes to share ipc with host (dmix uses it)
    #   --allow=multiarch - allow sandbox process to run 32-bit applications
    #   --filesystem=/home/me/Downloads - mount/share host folder with sandbox application
    #   --env=ALSA_CONFIG_DIR=  - discard alsa env vars
    #   --env=ALSA_CONFIG_PATH= - discard alsa env vars
    #   --env=SDL_AUDIODRIVER=alsa - tell SDL2 library to use alsa as audio backend
    #   --env=TEST_SOUND_FILE= - define which test sound file to uses in sandbox
	flatpak run -v --devel --cwd="$TEST_SHARED_FOLDER" --command="$TEST_SHARED_FOLDER/$AUDIO_TEST_PROGRAM" --device=all --share=ipc --allow=multiarch --filesystem=/home/me/Downloads --env=ALSA_CONFIG_DIR= --env=ALSA_CONFIG_PATH= --env=SDL_AUDIODRIVER=alsa --env=TEST_SOUND_FILE=$TEST_SOUND_FILE $RUNTIME
done
