#!/bin/sh -ex

# This script derends on RUNTIME envar
# In general, for each runtime we shall know which version of lib to build

# 1.1.9 is fine for all runtimes
ALSA=alsa-lib-1.1.9

# This program builds alsa-lib in a given flatpak SKD runtime, and prepare 
# custom installation which we use to override default alsa-lib in production 

# IMPORTANT: Normally this script is invoked by "build all runtime fixes.sh", which exports
#            3 env vars, $BUILDDIR, and $OUTPUT $BUILDHOST. If you intentd to use it outside this scope
#            define these variables manually

# Warn used if these variables are missing
if [ "$BUILDDIR" = "" ] || [ "$OUTPUT" = "" ] || [ "$BUILDHOST" = "" ]; then
    echo "Define BUILDDIR, OUTPUT and BUILDHOST env variables"
    exit
fi

# This is the folder where we collect all build results
PACKAGE=$OUTPUT/$BUILDHOST/$ALSA
mkdir -p $PACKAGE

# Define compiler dependent on BUILDHOST var
case $BUILDHOST in
    x86_64)
        export CC=gcc
        ;;
    i686)
        export PATH=$PATH:/usr/lib/sdk/toolchain-i386/bin/
        export CC=i686-unknown-linux-gnu-gcc
        ;;
    *)
        export CC=gcc
        ;;
esac

# Do all the work in this $BUILDDIR folder
cd $BUILDDIR

# download tar archive only once, this script is intended to run for each flatpak SDKruntime
# NOTE: wget is not abailable under flatpak runtimes
if [ ! -f alsa-lib-1.1.9.tar.bz2 ]; then
    curl -O http://mirrors.tassig.com/alsa-lib/alsa-lib-1.1.9.tar.bz2
fi

# We are operating under flatpak app SDK runtime
# runtime_info will associate built package with runtime used for building
cat /.flatpak-info | grep runtime= > $PACKAGE/runtime_info

# The whole work is split in 2 stages:

# Stage 1: build and install in the temporary dir
# 
# Form this stage we keep include/ and share/
# IMPORTANT: libasound.so.2.0.0 will have hardcoded --prefix, and won't be usable in runtime
#            alsa.pc file will also be affected by --prefix, won't be usable
mkdir install/
cd install/
INSTALL_PATH=$(pwd)
cd ../

tar xf $ALSA.tar.bz2
cd $ALSA
./configure --prefix="$INSTALL_PATH"

make -j
make install

cd ../
cp -r install/include $PACKAGE/
cp -r install/share $PACKAGE/
rm -r install

# do some cleanup
rm -r $PACKAGE/share/aclocal           # we simply don't need it

# NOTE: alsa-lib-1.1.9 don't use alsa.conf.d anymore, but Axiom still use this folder
# we have to provide this missing folder, and to tell alsa.conf to serch for it
mkdir -p "$PACKAGE"/share/alsa/alsa.conf.d
sed -i 's#"/etc/alsa/conf.d"#{\
			@func concat\
			strings [\
				{ @func datadir }\
				"/alsa.conf.d/"\
			]\
		}#' "$PACKAGE"/share/alsa/alsa.conf

# Stage 2: we build it again with default --prefix, we won't do any installation
#          now libasound.so.2.0.0 and alsa.pc will be usable in runtime
cd $ALSA
make clean
./configure 
make -j

cd ../
mkdir -p $PACKAGE/lib/pkgconfig
cp $ALSA/src/.libs/libasound.so.2.0.0 $PACKAGE/lib/
cp $ALSA/utils/alsa.pc $PACKAGE/lib/pkgconfig/

# Provide empty etc/alsa folder, to override default runtime contents with pulse
# TODO: perhaps this is not necessary
mkdir -p $PACKAGE/etc/alsa

# create symlink in $PACKAGE folder, flatpak alsa patch depends on it
ln -sv $ALSA $OUTPUT/$BUILDHOST/alsa

# remove source and temporary folders
rm -rf $ALSA
