#!/bin/sh -ex

# this script is part of flatpak building process
# xdg-desktop-portal is intended to be used with flatpak hutch only
# we provide patched portal, which implements integration with Axiom host
# depends on: flatpak 

rm -rf builddir
mkdir -p builddir
cd builddir

wget -O archive http://mirrors.tassig.com/xdg-desktop-portal/xdg-desktop-portal-1.7.2.tar.xz
tar xvf archive
rm archive
cd *   # cd into the package directory

# apply patches:
# Makefile.in.patch - adds axiom-impl* source files, to provide Axiom implementation
# xdg-desktop-portal-axiom.patch - redirect all available DBUS methods to log or Axiom implementation
patch -p1 < ../../xdg-desktop-portal-axiom/Makefile.in.patch
patch -p1 < ../../xdg-desktop-portal-axiom/xdg-desktop-portal-axiom.patch

# copy axiom-impl* source files
cp ../../xdg-desktop-portal-axiom/axiom-impl* src/

# prefix is not needed, we use only xdg-desktop-portal executable, no install will be done
# --disable-libportal - we don't need it
# --disable-geoclue - at the moment we don't provide it. TODO: is it useful?
# --disable-pipewire - we don't use it, https://pipewire.org/
./configure --disable-libportal --disable-geoclue --disable-pipewire
make -j

# just copy executable in flatpak's bin folder (and rename), and provide /bin symlink
cp xdg-desktop-portal /opt/flatpak/bin/xdg-desktop-portal-axiom
ln -sv /opt/flatpak/bin/xdg-desktop-portal-axiom /bin || true

cd ../..
rm -r builddir
