#include <stdlib.h>       /* malloc, free */
#include <sys/socket.h>   /* socket () */
#include <sys/un.h>       /* struct sockaddr_un */
#include <string.h>       /* strncpy, memset */
#include <unistd.h>       /* write() */
#include <errno.h>        /* errno */

#include <glib.h>         /* g_print */
#include "axiom-impl.h"   /* interface functions */


/* To keep this file clean, we provide implementation only for methods supported on Axiom */

/* host socket interface and protocol */
#define HOST_UNIX_SOCKET_PATH "/tmp/hutchr-desktop-portal.unix"

/* Add new commands here */
#define CMD_OPEN_URL 0x01


int fd = 0;
struct sockaddr_un addr;
int is_host_socket_open = 0;
char *msg_buff = 0;

int host_unix_socket_open (const char *path)
{
    /* open new socket */
    if((fd = socket(AF_UNIX, SOCK_DGRAM, 0)) == -1)
    {
        g_print ("XDG-DESKTOP-PORTAL-AXIOM: Error: failed to create socket: %s\n", path);
        return -1;
    }

    /* zero pad and setup socket path */
    memset(&addr, 0, sizeof(addr));
    addr.sun_family = AF_UNIX;
    strcpy(addr.sun_path, HOST_UNIX_SOCKET_PATH);
    if( connect( fd, (const struct sockaddr *)&addr, sizeof(addr)))
    {
        g_print ("XDG-DESKTOP-PORTAL-AXIOM: Error: failed to connect to socket: %s\n", path);
        return -1;
    }

    is_host_socket_open = 1;
    return 0;
}

void pack_int( char *buf, int val)
{
    buf[0] = (char)val & 0xff;
    buf[1] = (char)(val >> 8) & 0xff;
    buf[2] = (char)(val >> 16) & 0xff;
    buf[3] = (char)(val >> 24) & 0xff;
}

void pack_string( char *buf, const char *str, int str_sz)
{
    pack_int( buf, str_sz);
    pack_int( &buf[4], str_sz);
    strncpy ( &msg_buff[8], str, str_sz);
}

/* OpenURI Interface */
void axiom_impl_OpenURI_OpenURI (const char *arg_uri)
{
    g_print ("XDG-DESKTOP-PORTAL-AXIOM: OpenURI: OpenURI call: %s\n", arg_uri);

    if( !host_unix_socket_open (HOST_UNIX_SOCKET_PATH))
    {
        int uri_sz = 0;
        uri_sz = strlen( arg_uri);
        int msg_size = (uri_sz + 8); // 4 bytes of code and 4 bytes of length
        int written = 0;

        msg_buff = malloc (msg_size);
        if (msg_buff)
        {
            pack_int( &msg_buff[0], CMD_OPEN_URL);
            pack_string( &msg_buff[4], arg_uri, uri_sz);
            written = write(fd, msg_buff, msg_size);
            if (written == -1)
                g_print ("XDG-DESKTOP-PORTAL-AXIOM: errno %d\n", errno);
            free (msg_buff);
        }
        close( fd);
    }
}

int axiom_impl_init (void)
{
    g_print ("XDG-DESKTOP-PORTAL-AXIOM: axiom-impl-init\n");
    return 0;
}
