package_name=qemu
package_version=5.0.0
tarball_suffix=xz
build_dependencies="flex bison glib python3 sdl2"
no_check=1

# QEMU build will find stuff on your system if it's here, and link to it! It seems that they find a "use" for everything that they can find on your system

# - to make a faster build for amd64 only, add --target-list=x86_64-linux-user to configure



# NOTE: make sure there is no libudev.pc or udev.pc in pkg-config directory, so that qemu doesn't think udev is present


defaultbuild(){
	builddir="builddir-$package_fullname"  # build directory is "builddir" followed by the name of the package, which allows multiple builds of different software in parallel
	rm -rf $builddir
	mkdir -p $builddir   # do everything in builddir for tidiness
	cd $builddir
	wget -O archive $url
	tar xvf archive
	rm archive
	cd *   # cd into the package directory
	
	
	# musl patches
	cp ../../packages/extended/qemu/musl.patch linux-user/
	cd linux-user/
	patch -i musl.patch
	cd ../
	
	export CC=gcc   # TODO: but if /bin/cc doesn't work, the build doesn't work
	
	# - nettle shouldn't be there anyway, but if it is, disable it, not useful
	# - gcrypt: same rationale as nettle
	# - opengl support doesn't build properly
	# - seccomp support will be built if it's found, and this is useless
	./configure --prefix=$installdirectory/$package_fullname/ --disable-nettle --disable-gcrypt --disable-seccomp --extra-ldflags="-Wl,-rpath,/opt/glib/lib -Wl,-rpath,/opt/curl/lib -Wl,-rpath,/opt/libxml2/lib -Wl,-rpath,/opt/libpng/lib -Wl,-rpath,/opt/bluez/lib -Wl,-rpath,/opt/xorg/lib -Wl,-rpath,/opt/libepoxy/lib" --extra-cflags="-I/opt/libepoxy/include -I/opt/xorg/include"
	
	
	ncpu=`cat /proc/cpuinfo | grep processor | wc -l`
	make -j$ncpu
	if test -z $no_check   # run the make check, unless $no_check is set for this package definition
	then make -j$ncpu check || make -j$ncpu test
	fi
	make install
	
	
	ln -snv $installdirectory/$package_fullname $installdirectory/$package_name || true   # if $package_name already exists (for example, another version is already installed), don't overwrite, and don't crash
	ln -sv $installdirectory/$package_name/bin/* $bindirectory || true   # don't crash if the links are already there
	if [ -d "$installdirectory/$package_fullname/lib/pkgconfig" ]; then
		ln -svf $installdirectory/$package_fullname/lib/pkgconfig/* $installdirectory/pkgconf/lib/pkgconfig/   # symlink pkg-config files
	fi
	# NOTE: .m4 files should probably be installed as well by default, but i have no strong opinion on it, so for now we leave this to the postinstall() function
	cd ../..
	rm -r $builddir
}
