package_name="qt-creator"
package_version="4.6"
build_dependencies="qt"
tarball_suffix=gz
iscustombuild=1



# TODO: there is a problem with qtcreator with recent musl (it's fine with old one), may have something to do with libexecinfo


# NOTE: when running in a hutch, /opt/xorg must be there, the dri drivers as well (libva, vdpau, llvm), thus /opt/libressl must be there as well as a dependency of these dri drivers


custombuild(){

	# qt-creator depends on libexecinfo (which is not provided by ports, so we'll simply pack it with qt-creator)

	# IMPORTANT NOTE: qt-creator is not able to build at a path that contains spaces!

	# NOTE: qt-creator version we can use is limited by available qt version from ports.git
	#       since we currently provide qt-5.7.0, we are limited to use qt-creator 4.6 
	#       refer to README.md file in the qt-creator source tree

	# do build in the temporary folder, for tidyness
	rm -rf builddir
	mkdir -p builddir
	cd builddir


	# build libexecinfo, following qt-creator modules requires it: plugins/debugger/ and plugins/qmldesigner
	# libexecinfo is normally part of glibc, and since we use musl, we'll have to use one version available as replacement
	# NOTE: alpine linux also provide libexecinfo as an external package, we could also provide it in ports, but because nothing else uses it so far, and because qt-creator is likely to drop this requirement in the future, there is no point in doing it

	# NOTE: more details on how we will do it, will be given below, in the qt-creator build preparation steps
	wget http://mirrors.tassig.com/libexecinfo/libexecinfo-1.1-3.tar.gz
	tar xf libexecinfo-1.1-3.tar.gz
	cd libexecinfo-1.1-3
	make CC=gcc
	cp libexecinfo.so.1 libexecinfo.so  # this is exactly what qt-creator expects, we don't need to make symlink
	cd ../
	libexecinfo_path=`pwd`/libexecinfo-1.1-3

	# official qt-creator building procedure: 
	# https://wiki.qt.io/Building_Qt_Creator_from_Git#Getting_the_source_code 
	
	
	package_full_name=$package_name-$package_version

	# get qt-creator sources form our mirror
	wget http://mirrors.tassig.com/qt-creator/$package_full_name.tar.$tarball_suffix
	tar xf $package_full_name.tar.gz
	cd $package_full_name

	# add additional include and link paths to qt-creator.pri:
	sed -i '182a \  ' qtcreator.pri
	sed -i "182a \QMAKE_LFLAGS += -Wl,-rpath=/opt/xorg/lib" qtcreator.pri  # avoid using LD_LIBRARY_PATH later on
	sed -i "182a \LIBS += -L$libexecinfo_path" qtcreator.pri               # add link path for libexecinfo
	sed -i "182a \LIBS += -lexecinfo" qtcreator.pri                        # add link flag for libexecinfo
	sed -i "182a \INCLUDEPATH += /opt/xorg/include" qtcreator.pri          # fix missing include GL/gl.h
	sed -i "182a \INCLUDEPATH += $libexecinfo_path" qtcreator.pri          # add include path for libexecinfo

	# now follow the procedure for qt-creator building
	cd ../
	mkdir qt-creator-build
	cd qt-creator-build
	qmake ../$package_full_name/qtcreator.pro
	
	make qmake_all

	ncpu=`cat /proc/cpuinfo | grep processor | wc -l`
	make -j$ncpu

	make install INSTALL_ROOT="$installdirectory/$package_full_name"

	# copy libexecinfo.so.1 at the standard run path of qt-creator
	cp ../libexecinfo-1.1-3/libexecinfo.so.1 $installdirectory/$package_full_name/lib/qtcreator/

	# make a final symlink
	ln -svf $installdirectory/$package_full_name/bin/qtcreator $bindir/qtcreator || true

	cd ../..
	rm -rf builddir
}
