#!/bin/sh -ex

package_name=cndrvcups-common
package_version=3.21-1
tarball_suffix=gz
package_fullname=$package_name-$package_version
ports_build_dependencies="libxml2 libglade automake perl cups"
build_dependencies=""

url=http://mirrors.tassig.com/$package_name/$package_fullname.tar.$tarball_suffix
installdirectory=/opt
BUILD_DIR=/home/work/

ACTION=$1

function premake(){
	
	local INCLUDES="-I$installdirectory/cups/include \
		-I$installdirectory/libglade/include \
		"
	local TOOLS="cngplp buftool backend"

	for TOOL in $TOOLS;
	do
		export CFLAGS="$INCLUDES"
		export CXXFLAGS="$INCLUDES"
		export LDFLAGS="-L$installdirectory/cups/lib \
			-Wl,-rpath,$installdirectory/cups/lib \
			-L$installdirectory/libglade/lib \
			-Wl,-rpath,$installdirectory/libglade/lib \
			"
		( cd $TOOL;
		sed -i 's/confdir = \/usr\/share\/cngplp/confdir = $(datarootdir)/g' src/Makefile.am;
		./autogen.sh --prefix=$installdirectory/$package_fullname --exec-prefix=$installdirectory/$package_fullname;
		) || exit 1
	done
}

function domake(){
	make -j
}

function doinstall(){
	make install
}

function postinstall(){
	ln -svf "$installdirectory/$package_fullname" "$installdirectory/$package_name"
	if [ -d "$installdirectory/$package_name/lib/pkgconfig" ]; then
		ln -svf $installdirectory/$package_name/lib/pkgconfig/* \
		$installdirectory/pkgconf/lib/pkgconfig/   # install pkg-config files
	fi
	ln -svf "$installdirectory/$package_name/bin"/* "/bin/"
	ln -svf "$installdirectory/$package_name/lib/cups/backend"/* \
		"$installdirectory/cups/lib/cups/backend/"

}

function install_ports_deps(){
	if [ "$ports_build_dependencies" == "" ]; then
		return
	fi
	local START_DIR=`pwd`
	rm -rf "$BUILD_DIR"
	mkdir -p "$BUILD_DIR"
	cd "$BUILD_DIR"

	GIT_SSH_COMMAND="ssh -y" sshpass -p "temppassrobotbuilder" git clone ssh://robotbuilder@git.cacaoweb.org/../var/git/ports.git
	cd ports

	for pkg_name in $ports_build_dependencies
	do
		(./packageinstall.sh $pkg_name) || exit $?
	done

	cd ..
	rm -rf ports
	cd "$START_DIR"
}

function install_deps(){
	if [ "$build_dependencies" == "" ]; then
		return
	fi
	for pkg_name in $build_dependencies
	do
		(./$pkg_name.sh install) || exit $?
	done
}

function install(){
	[ -e "$installdirectory/$package_name" ] && {
		echo "$package_name is already installed"
		exit 0
	}

	install_ports_deps
	install_deps
	local START_DIR=`pwd`
	
	rm -rf "$BUILD_DIR"
	mkdir -p "$BUILD_DIR"
	cd "$BUILD_DIR"

	wget -O archive $url
	tar xvf archive
	rm archive

	cd *
	premake
	domake
	doinstall
	postinstall
	cd "$START_DIR"
}



case $ACTION in
	install)
		install
	;;
	remove)
		remove
	;;
	*)
		echo "$0 <install|remove>"
	;;
esac



