#!/bin/sh

set -ex

# before we run this script we need to prepare dependences
# follow these steps:
#    clone ports.git
#    cd ports/
#    ./packageinstall.sh nasm      # ffmpg depends on nasm
#    ./packageinstall.sh python2   # mpv.sh depends on python2
#    ./packageinstall.sh libass    # mpv.sh depends on libass
#    ./packageinstall.sh lua
#
#    cd to where hutchr was cloned
#    cd hutchr/applications
#    sh ffmpeg.sh
#    sh mpv.sh
#    rm -r /opt/ffmpeg*


package_name=mpv
package_version=0.29.1
tarball_suffix=gz

installdirectory="/opt"   # mpv is installed globally, to /opt
mirror_prefix=http://mirrors.tassig.com
package_fullname=$package_name-$package_version 
url=$mirror_prefix/$package_name/$package_fullname.tar.$tarball_suffix



rm -rf builddir
mkdir -p builddir   # do everything in builddir for tidiness
cd builddir
wget -O archive $url
tar xvf archive
rm archive
cd *   # cd into the package directory

python bootstrap.py

export CC=gcc

CFLAGS="-I/opt/zlib/include -I/opt/libva/include" \
	LDFLAGS="-L/opt/zlib/lib \
		-Wl,-rpath,/opt/zlib/lib \
		-L/opt/libva/lib \
		-Wl,-rpath,/opt/libva/lib \
		-L/opt/libvdpau/lib/ \
		-Wl,-rpath,/opt/libvdpau/lib \
		-Wl,-rpath=/opt/xorg/lib \
		-Wl,-rpath=/opt/alsa-lib/lib \
		-Wl,-rpath=/opt/libass/lib " \
	python ./waf configure --prefix=$installdirectory/$package_fullname
python ./waf build
python ./waf install

ln -snv $installdirectory/$package_fullname $installdirectory/$package_name
ln -sv $installdirectory/$package_name/bin/* /bin/ || true   # don't crash if the links are already there
if [ -d "$installdirectory/$package_name/lib/pkgconfig" ]; then
	ln -svf $installdirectory/$package_name/lib/pkgconfig/* \
	$installdirectory/pkgconf/lib/pkgconfig/   # install pkg-config files
fi
cd ../..
rm -r builddir

strip $installdirectory/$package_fullname/bin/*

