# kBuild is a build framework which is used to build VirtualBox
# and Guest Additions
#
# if texinfo wasn't installed on the system, remove it at the end of the build


############################################
#
# prerequisites:
# - texinfo (from ports.git), which provides makeinfo, which is needed by parts of the build. TODO: the full bootstrap procedure does not need makeinfo, so there is something different
#
############################################

# texinfo is needed for a proper building of the kBuild
if [ ! -d "/opt/texinfo" ]; then
	echo "texinfo package is required"
	exit
fi

set -ex

export vboxdir="$(pwd)"   # directory where our patches and scripts reside

export build_dir=/home/work/tmpbuild
mkdir -p $build_dir
cd $build_dir

# download
# tarballs are not provided upstream, so we prepare our own tarball from the svn trunk with: svn co http://svn.netlabs.org/repos/kbuild/trunk
# and a file SvnInfo.kmk needs to be added to the root for version information
wget -O archive http://mirrors.tassig.com/kBuild/kBuild.tar.gz
tar xf archive
rm archive


# build kBuild
# We use the following manual to do that http://trac.netlabs.org/kbuild/wiki/Bootstrapping
cd kBuild/

# patches
patch -p1 < "$vboxdir/kBuild patches/kBuild_chmod.patch"
patch -p1 < "$vboxdir/kBuild patches/kBuild_ftsfake.patch"
patch -p1 < "$vboxdir/kBuild patches/kBuild_fts.patch"
patch -p1 < "$vboxdir/kBuild patches/kBuild_install.patch"
patch -p1 < "$vboxdir/kBuild patches/kBuild_all_Makefile.patch"
patch -p1 < "$vboxdir/kBuild patches/kBuild_kDefs.patch"
patch -p1 < "$vboxdir/kBuild patches/kBuild_kObjCache.patch"
patch -p1 < "$vboxdir/kBuild patches/kBuild_sed_Makefile.patch"


# we don't build kmk_ash, because it's hard to build and because ash should be enough for all intents and purposes, so this is a hack
echo '#!/bin/sh' > kBuild/bin/linux.amd64/kmk_ash
echo 'exec /opt/busybox/bin/busybox sh $*' >> kBuild/bin/linux.amd64/kmk_ash
chmod u+x kBuild/bin/linux.amd64/kmk_ash


# build all binaries
kBuild/env.sh --full make -f bootstrap.gmk

# rebuild all binaries, using kmk that we just built, but this step is unnecessary in production
#kBuild/env.sh kmk rebuild PATH_INS=`pwd`



echo "Build done, resulting binaries in kBuild/bin/linux.amd64/ directory"

exit 0







###############################
#
# full bootstrap procedure
# this works but is not necessary for us on amd64 in production, however it is useful for development and to solve bugs in the build
#
###############################

# setting environment variables for the build
if [ -z "$KBUILD_HOST" ]; then
	kBuild/env.sh --full # TODO: this stops the script execution because it's spawning another process, we can restart the current process by doing exit or something like that
fi


# kBuild require fts header but musl doesn't have it.
# We need to use ftsfake.h instead of fts.h
# TODO: probably useless
mkdir -p $build_dir/fts
cp ./src/kmk/kmkbuiltin/ftsfake.h $build_dir/fts/fts.h


# building just kmk
cd src/kmk
autoreconf -i
CFLAGS="-I$build_dir/fts/" ./configure
make

# place required files to the final folder
cp ./kmk ../../kBuild/bin/linux.amd64/
cp ./kmk_redirect ../../kBuild/bin/linux.amd64/

# build all the binaries
cd ..
kmk

# kmk_ash might be hard to build, and probably not very useful, so we don't build it
# example: syntax error line 168 at ash/Makefile.kmk, can be replaced by true instead
# solution: we remove ash from src/Makefile.kmk


# copy the produced binaries
cd ..
cp out/linux.amd64/release/stage/kBuild/bin/linux.amd64/* kBuild/bin/linux.amd64/

# rebuild with the produced binaries and copy them
rm -r out
kmk
cp out/linux.amd64/release/stage/kBuild/bin/linux.amd64/* kBuild/bin/linux.amd64/


# rebuild again, this time we should have reached the fixpoint, which we could check by comparing the binaries (we don't do that here)
rm -r out
kmk
cp out/linux.amd64/release/stage/kBuild/bin/linux.amd64/* kBuild/bin/linux.amd64/

set +ex

