#!/bin/sh



set -ex

VBox_version=5.1.34



###########################################
#
# build virtualbox guest additions
#
# prerequisites: 
# - makeself in PATH (http://stephanepeter.com/makeself/)
# - kBuild (the one that we built ourself)
# - yasm (from ports.git)
# - python2 (from ports.git)
# - bc (from ports.git)

# TODO: install iasl from https://acpica.org/downloads (install works fine)

# TODO: install mkisofs (from cdrtools) from http://www.linuxfromscratch.org/blfs/view/svn/multimedia/cdrtools.html (make sure to check the linuxfromscratch instructions)

# TODO: install libIDL from http://ftp.gnome.org/pub/gnome/sources/libIDL/0.8/libIDL-0.8.14.tar.bz2 (installation is clean)

# TODO: you need to re-install libressl, with the static libraries because this build will use them. This can be done from ports.git, by modifying the postinstall function (remove the clean up). You also need to do "export CFLAGS="-fPIC"" because it seems vbox wants that

# TODO: libcap from https://mirrors.edge.kernel.org/pub/linux/libs/security/linux-privs/libcap2/libcap-2.27.tar.gz
#
###########################################



if [ ! -f "/bin/yasm" ]; then
	echo "yasm package is required"
	exit
fi

if [ ! -f "/bin/python" ]; then
	echo "python2 package is required"
	exit
fi

# TODO: not sure if the following 2 are needed
if [ ! -f "/bin/bc" ]; then
        echo "bc package is required"
        exit
fi

if [ ! -f "/bin/xz" ]; then
        echo "xz package is required"
        exit
fi



export scriptpwd=$PWD

export build_dir=/home/work/tmpbuild
mkdir -p $build_dir
cd $build_dir

# makeself
wget -O makeself http://mirrors.tassig.com/megastep/megastep-makeself-release-2.3.0-4-g820c84a.tar
tar xvf makeself
cp megastep-makeself-*/makeself.sh /bin/makeself
chmod +x /bin/makeself

# virtualbox
cd $build_dir
wget http://mirrors.tassig.com/virtualbox/VirtualBox-$VBox_version.tar.bz2
tar xvf VirtualBox-$VBox_version.tar.bz2
cd VirtualBox-$VBox_version

# patches
cp "$scriptpwd/guest additions patches/"* ./   # TODO: rename directory "guest additions"
patch -p1 < kDefs.patch
patch -p1 < musl-fix-headers.patch
patch -p1 < musl-no-glibc.patch
patch -p1 < musl-fix-stat-nsec.patch
patch -p1 < futimens.patch
patch -p1 < musl-sched_yield.patch
patch -p1 < configure.patch
patch -p1 < undefined_xorg.patch
patch -p1 < VBoxClient_Makefile.kmk.patch
patch -p1 < vboxclient.patch
patch -p1 < vboxclient_clipboard.patch

# circumventing a bug
# zlib header inclusion for some files, because there is some issue in some script with space. I did not dig to find the bug
ln -sv /opt/zlib/include/* src/VBox/Runtime/include/
ln -sv /opt/curl/include/* src/VBox/Runtime/include/


#ln -sv /opt/xorg/include/* include/



export kbuild_directory=$build_dir/"kBuild/kBuild" # set this to our kBuild directory


# NOTE: the configure script is patched, mainly because it's hand written and doesn't use pkg-config
./configure --with-kbuild=$kbuild_directory --disable-python --disable-java  --disable-dbus  --disable-docs --disable-libvpx --disable-udptunnel --with-iasl=/home/jerry/Downloads/acpica-unix-20190509/generate/unix/bin/iasl --with-openssl-dir=/opt/libressl-2.9.1 --disable-pulse --disable-sdl --disable-alsa --disable-devmapper --disable-vmmraw --disable-hardening

# explanations:
# - --disable-vmmraw : our gcc does not have multilib support, so we cannot build the guest additions for 32bits guests
# - --disable-hardening : some code related to hardening didn't seem to compile without some effort, so i added this flag to make progress on compilation
# - other disable switches are just for convenience and don't seem to remove important functionality so i didn't bother with them



source env.sh   # set up some environment variables

export USER="root"   # needed, otherwise get kmk_sed errors

kmk   # KBUILD_VERBOSE=2

# TODO: the build has the following issues:
# * at some point, a file is including glib.h, but nowhere in the configure part is there anything to find glib paths. This is fixed by linking these headers somewhere where the build is looking at. A better fix ca be done by looking for "libIDL_config_cflags", and setting VBOX_LIBIDL_CONFIG   = "/bin/libIDL-config-2" just before. I didn't dig deeper, it seems "VBOX_LIBIDL_CONFIG             := PKG_CONFIG_PATH=/opt/libIDL/lib64/pkgconfig /bin/libIDL-config-2" in AutoConfig.kmk doesn't work
# * the build fails with a strange error with kmk_sed building a header file, cannot reproduce the error when running manually. After running this command manually the build works fine, but sometimes it's still stuck. Playing with the Makefile, creating the output file by running kmk_sed manually works. I don't know why kmk_sed sometimes throws a "usage" error when run from the Makefile, but not manually.
# * some errors seem to be weird errors from the shell, like the one above, because running the command manually works, and then you can continue the build
# * it seems some dependencies are not very clean in the build, so running a parallel build sometimes fail. We have to see if running the build sequentially works fine. Use kmk -j1
# * the build will fail with the following error: VBoxTpG: error: Failed to start 'yasm'
#   this error is quite internal to VBoxTPG, so fixing it would require digging in the source and try to understand it
#   when running yasm manually with the same arguments, it works fine, like:
# yasm -f elf64 -D ASM_FORMAT_ELF -D ARCH_BITS=64 -D HC_ARCH_BITS=64 -D RT_ARCH_AMD64 -D IN_RING3 -D RT_OS_LINUX -I /home/work/tmpbuild/VirtualBox-5.1.34/include/ -o /home/work/tmpbuild/VirtualBox-5.1.34/out/linux.amd64/release/obj/RuntimeR0/dtrace/VBoxVMM-dtrace-object-format.o /home/work/tmpbuild/VirtualBox-5.1.34/out/linux.amd64/release/obj/RuntimeR0/dtrace/VBoxVMM-dtrace-object-format.o.asm
#   so this bug can be worked around easily by generating the asm file and then running yasm manually, for example one can put an "exit(0)" before the call RTProcCreate()
# * need to remove an include to glu.h , i'm not sure what glu.h is but removing it doesn't break the build
# * the final linking commands sometimes are missing -L flags. As a workaround you can move the corresponding libraries into /lib/ temporarily for the purpose of making linking work, or change the Makefiles
# * the build ultimately fails with a compilation error in VBoxAcpi.cpp, i didn't investigate


# TODO: can do temporarily:
export LD_LIBRARY_PATH=/opt/libIDL/lib:/opt/glib/lib




##########################
#
# install
#
##########################

mkdir -p /opt/VirtualBox-$VBox_version/bin
cp $build_dir/VirtualBox-$VBox_version/out/linux.amd64/release/bin/additions/VBoxClient /opt/VirtualBox-$VBox_version/bin/
cp $build_dir/VirtualBox-$VBox_version/out/linux.amd64/release/bin/additions/mount.vboxsf /opt/VirtualBox-$VBox_version/bin/
ln -sv /opt/VirtualBox-$VBox_version /opt/VirtualBox
ln -sv /opt/VirtualBox/bin/* /bin/



##########################
#
# cleanup
#
##########################
rm /bin/makeself
rm -r $build_dir

